@@ -44,6 +44,7 @@ from debusine.artifacts import (
 )
 from debusine.assets import AssetCategory, asset_data_model
 from debusine.client import exceptions
+from debusine.client.client_utils import get_debian_package
 from debusine.client.config import ConfigHandler
 from debusine.client.debusine import Debusine
 from debusine.client.exceptions import DebusineError
@@ -57,7 +58,6 @@ from debusine.client.models import (
     model_to_json_serializable_dict,
     model_to_json_serializable_list,
 )
-from debusine.client.utils import get_debian_package
 
 
 class Cli:
