@@ -291,7 +291,7 @@ class DebusineHttpClientTests(TestCase):
     )
     @responses.activate(registry=OrderedRegistry)
     def test_api_request_retry_errors(self) -> None:  # pragma: no cover
-        """Some HTTP error responsese are retried."""
+        """Some HTTP error responses are retried."""
         debusine_client = DebusineHttpClient(self.api_url, self.token)
 
         for code in (
@@ -364,7 +364,7 @@ class DebusineHttpClientTests(TestCase):
         self.assert_token_key_included_in_all_requests(self.token)
 
     def test_api_request_create_and_use_session(self) -> None:
-        """_api_request method create a session, uses and re-uses it."""
+        """_api_request method create a session, uses and reuses it."""
         session_patch = mock.patch("requests.Session", autospec=True)
         session_mock = session_patch.start()
         self.addCleanup(session_patch.stop)
@@ -389,7 +389,7 @@ class DebusineHttpClientTests(TestCase):
         with self.assertRaises(exceptions.UnexpectedResponseError):
             debusine_client._api_request("GET", self.api_url, TestResponse)
 
-        # Same session re-used
+        # Same session reused
         self.assertIs(debusine_client._session, session)
 
     def test_api_request_no_token(self) -> None:
