@@ -37,7 +37,7 @@ from debusine.client.models import (
     model_to_json_serializable_dict,
 )
 from debusine.test import TestCase
-from debusine.test.utils import (
+from debusine.test.test_utils import (
     create_artifact_response,
     create_work_request_response,
 )
