@@ -31,8 +31,8 @@ from debusine.assets import KeyPurpose
 from debusine.client.models import LookupChildType
 from debusine.db.models import (
     DEFAULT_FILE_STORE_NAME,
-    DEFAULT_WORKSPACE_NAME,
     FileStore,
+    Group,
     SYSTEM_USER_NAME,
     User,
     WorkRequest,
@@ -203,7 +203,7 @@ class MigrationTests(TestCase):
         executor.migrate(migrate_from)
         old_apps = executor.loader.project_state(migrate_from).apps
         workspace = old_apps.get_model("db", "Workspace").objects.get(
-            name=DEFAULT_WORKSPACE_NAME
+            name=settings.DEBUSINE_DEFAULT_WORKSPACE
         )
         for category, data in old_artifacts:
             old_apps.get_model("db", "Artifact").objects.create(
@@ -251,7 +251,7 @@ class MigrationTests(TestCase):
         executor.migrate([("db", migrate_from)])
         old_apps = executor.loader.project_state([("db", migrate_from)]).apps
         workspace = old_apps.get_model("db", "Workspace").objects.get(
-            name=DEFAULT_WORKSPACE_NAME
+            name=settings.DEBUSINE_DEFAULT_WORKSPACE
         )
         for task_name, task_data in old_work_requests:
             old_apps.get_model("db", "WorkRequest").objects.create(
@@ -390,7 +390,7 @@ class MigrationTests(TestCase):
         executor.migrate(migrate_from)
         old_apps = executor.loader.project_state(migrate_from).apps
         workspace = old_apps.get_model("db", "Workspace").objects.get(
-            name=DEFAULT_WORKSPACE_NAME
+            name=settings.DEBUSINE_DEFAULT_WORKSPACE
         )
         for task_type in ("worker", "server", "internal", "workflow"):
             old_apps.get_model("db", "WorkRequest").objects.create(
@@ -726,7 +726,7 @@ class MigrationTests(TestCase):
         old_apps = executor.loader.project_state(migrate_from).apps
         Collection = old_apps.get_model("db", "Collection")
         workspace = old_apps.get_model("db", "Workspace").objects.get(
-            name=DEFAULT_WORKSPACE_NAME
+            name=settings.DEBUSINE_DEFAULT_WORKSPACE
         )
         Collection.objects.create(
             name="test",
@@ -820,7 +820,7 @@ class MigrationTests(TestCase):
         executor.migrate(migrate_from)
         old_apps = executor.loader.project_state(migrate_from).apps
         workspace = old_apps.get_model("db", "Workspace").objects.get(
-            name=DEFAULT_WORKSPACE_NAME
+            name=settings.DEBUSINE_DEFAULT_WORKSPACE
         )
         for task_type, task_name, task_data in old_work_requests:
             old_apps.get_model("db", "WorkRequest").objects.create(
@@ -922,7 +922,7 @@ class MigrationTests(TestCase):
         executor.migrate(migrate_from)
         old_apps = executor.loader.project_state(migrate_from).apps
         workspace = old_apps.get_model("db", "Workspace").objects.get(
-            name=DEFAULT_WORKSPACE_NAME
+            name=settings.DEBUSINE_DEFAULT_WORKSPACE
         )
         collection_test = old_apps.get_model("db", "Collection").objects.create(
             name="test", category=CollectionCategory.TEST, workspace=workspace
@@ -991,7 +991,7 @@ class MigrationTests(TestCase):
 
         # The default workspace already exists.
         default_workspace = old_db_workspace.objects.get(
-            name=DEFAULT_WORKSPACE_NAME
+            name=settings.DEBUSINE_DEFAULT_WORKSPACE
         )
         # Create two other workspaces that share a file store.
         file_store = old_apps.get_model("db", "FileStore").objects.create(
@@ -1085,7 +1085,7 @@ class MigrationTests(TestCase):
         old_work_request_model = old_apps.get_model("db", "WorkRequest")
         old_workspace_model = old_apps.get_model("db", "Workspace")
         default_workspace = old_workspace_model.objects.get(
-            name=DEFAULT_WORKSPACE_NAME
+            name=settings.DEBUSINE_DEFAULT_WORKSPACE
         )
         test_user = self.get_test_user_for_apps(old_apps)
         expected_build_components = []
@@ -1145,7 +1145,7 @@ class MigrationTests(TestCase):
         old_file_store_model = old_apps.get_model("db", "FileStore")
         old_workspace_model = old_apps.get_model("db", "Workspace")
         old_default_workspace = old_workspace_model.objects.get(
-            name=DEFAULT_WORKSPACE_NAME
+            name=settings.DEBUSINE_DEFAULT_WORKSPACE
         )
         old_default_file_store = old_file_store_model.objects.get(
             name=DEFAULT_FILE_STORE_NAME
@@ -1162,7 +1162,7 @@ class MigrationTests(TestCase):
         new_workspace_model = new_apps.get_model("db", "Workspace")
         fallback_scope = scope_model.objects.get(name="debusine")
         new_default_workspace = new_workspace_model.objects.get(
-            name=DEFAULT_WORKSPACE_NAME
+            name=settings.DEBUSINE_DEFAULT_WORKSPACE
         )
         new_workspace = new_workspace_model.objects.get(name="test-migration")
 
@@ -1221,7 +1221,7 @@ class MigrationTests(TestCase):
         old_apps = executor.loader.project_state(migrate_from).apps
         old_work_request_model = old_apps.get_model("db", "WorkRequest")
         default_workspace = old_apps.get_model("db", "Workspace").objects.get(
-            name=DEFAULT_WORKSPACE_NAME
+            name=settings.DEBUSINE_DEFAULT_WORKSPACE
         )
         test_user = self.get_test_user_for_apps(old_apps)
         old_unsigned = [2, "internal@collections/name:unsigned"]
@@ -1298,7 +1298,7 @@ class MigrationTests(TestCase):
         executor.migrate(migrate_from)
         old_apps = executor.loader.project_state(migrate_from).apps
         default_workspace = old_apps.get_model("db", "Workspace").objects.get(
-            name=DEFAULT_WORKSPACE_NAME
+            name=settings.DEBUSINE_DEFAULT_WORKSPACE
         )
         test_user = self.get_test_user_for_apps(old_apps)
         work_request = old_apps.get_model("db", "WorkRequest").objects.create(
@@ -1336,7 +1336,7 @@ class MigrationTests(TestCase):
         executor.migrate(migrate_from)
         old_apps = executor.loader.project_state(migrate_from).apps
         default_workspace = old_apps.get_model("db", "Workspace").objects.get(
-            name=DEFAULT_WORKSPACE_NAME
+            name=settings.DEBUSINE_DEFAULT_WORKSPACE
         )
         test_user = self.get_test_user_for_apps(old_apps)
         work_request = old_apps.get_model("db", "WorkRequest").objects.create(
@@ -1380,7 +1380,7 @@ class MigrationTests(TestCase):
             old_apps.get_model("db", "Workspace")
             .objects.get(
                 scope__name=settings.DEBUSINE_DEFAULT_SCOPE,
-                name=DEFAULT_WORKSPACE_NAME,
+                name=settings.DEBUSINE_DEFAULT_WORKSPACE,
             )
             .public
         )
@@ -1392,7 +1392,7 @@ class MigrationTests(TestCase):
             new_apps.get_model("db", "Workspace")
             .objects.get(
                 scope__name=settings.DEBUSINE_DEFAULT_SCOPE,
-                name=DEFAULT_WORKSPACE_NAME,
+                name=settings.DEBUSINE_DEFAULT_WORKSPACE,
             )
             .public
         )
@@ -1419,7 +1419,7 @@ class MigrationTests(TestCase):
                 name="_",
                 category__in=singleton_collection_categories,
                 workspace__scope__name=settings.DEBUSINE_DEFAULT_SCOPE,
-                workspace__name=DEFAULT_WORKSPACE_NAME,
+                workspace__name=settings.DEBUSINE_DEFAULT_WORKSPACE,
             )
             .values_list("category", flat=True),
             [],
@@ -1434,7 +1434,7 @@ class MigrationTests(TestCase):
                 name="_",
                 category__in=singleton_collection_categories,
                 workspace__scope__name=settings.DEBUSINE_DEFAULT_SCOPE,
-                workspace__name=DEFAULT_WORKSPACE_NAME,
+                workspace__name=settings.DEBUSINE_DEFAULT_WORKSPACE,
             )
             .values_list("category", flat=True),
             singleton_collection_categories,
@@ -1457,7 +1457,7 @@ class MigrationTests(TestCase):
             task_name="piuparts",
             created_by_id=self.get_test_user_for_apps(old_apps).id,
             workspace=old_apps.get_model("db", "Workspace").objects.get(
-                name=DEFAULT_WORKSPACE_NAME
+                name=settings.DEBUSINE_DEFAULT_WORKSPACE
             ),
             task_data={
                 "purpose": KeyPurpose.UEFI,
@@ -1514,7 +1514,7 @@ class MigrationTests(TestCase):
         old_apps = executor.loader.project_state(migrate_from).apps
         workspace = old_apps.get_model("db", "Workspace").objects.get(
             scope__name=settings.DEBUSINE_DEFAULT_SCOPE,
-            name=DEFAULT_WORKSPACE_NAME,
+            name=settings.DEBUSINE_DEFAULT_WORKSPACE,
         )
         now = timezone.now()
 
@@ -1778,7 +1778,7 @@ class MigrationTests(TestCase):
         old_apps = executor.loader.project_state(migrate_from).apps
         workspace = old_apps.get_model("db", "Workspace").objects.get(
             scope__name=settings.DEBUSINE_DEFAULT_SCOPE,
-            name=DEFAULT_WORKSPACE_NAME,
+            name=settings.DEBUSINE_DEFAULT_WORKSPACE,
         )
 
         old_work_requests = [
@@ -1928,7 +1928,7 @@ class MigrationTests(TestCase):
             created_by_id=self.get_test_user_for_apps(old_apps).id,
             task_name="foo",
             workspace=old_apps.get_model("db", "Workspace").objects.get(
-                name=DEFAULT_WORKSPACE_NAME
+                name=settings.DEBUSINE_DEFAULT_WORKSPACE
             ),
             workflow_runtime_status="Needs Input",
         )
@@ -1971,7 +1971,7 @@ class MigrationTests(TestCase):
         old_apps = executor.loader.project_state(migrate_from).apps
 
         default_workspace = old_apps.get_model("db", "Workspace").objects.get(
-            name=DEFAULT_WORKSPACE_NAME
+            name=settings.DEBUSINE_DEFAULT_WORKSPACE
         )
         OldArtifact = old_apps.get_model("db", "Artifact")
         OldWorkRequest = old_apps.get_model("db", "WorkRequest")
@@ -2224,7 +2224,7 @@ class MigrationTests(TestCase):
         old_apps = executor.loader.project_state(migrate_from).apps
         workspace = old_apps.get_model("db", "Workspace").objects.get(
             scope__name=settings.DEBUSINE_DEFAULT_SCOPE,
-            name=DEFAULT_WORKSPACE_NAME,
+            name=settings.DEBUSINE_DEFAULT_WORKSPACE,
         )
 
         # list of (category, data)
@@ -2545,3 +2545,78 @@ class MigrationTests(TestCase):
             [("filestore0", None), ("filestore1", None)],
             ordered=False,
         )
+
+    def test_group_user_through(self) -> None:
+        """Test converting user-group m2m to through model."""
+        migrate_from = [("db", "0135_workerpools")]
+        migrate_to = [("db", "0136_add_groupmembership")]
+
+        executor = MigrationExecutor(
+            connection, progress_callback=_migrate_check_constraints
+        )
+        executor.migrate(migrate_from)
+        old_apps = executor.loader.project_state(migrate_from).apps
+        OldScope = old_apps.get_model("db", "Scope")
+        OldGroup = old_apps.get_model("db", "Group")
+        old_user = self.get_test_user_for_apps(old_apps)
+        old_scope = OldScope.objects.create(name="scope")
+        old_group = OldGroup.objects.create(scope=old_scope, name="group")
+        old_group.users.add(old_user)
+
+        executor.loader.build_graph()
+        executor.migrate(migrate_to)
+
+        new_apps = executor.loader.project_state(migrate_to).apps
+        NewGroup = new_apps.get_model("db", "Group")
+        new_user = self.get_test_user_for_apps(new_apps)
+        new_group = NewGroup.objects.get(name="group")
+        # user is still a member
+        self.assertQuerySetEqual(new_group.users.all(), [new_user])
+        membership = new_group.membership.first()
+        # we have a through table
+        self.assertEqual(membership._meta.label, "db.GroupMembership")
+        self.assertEqual(membership.group, new_group)
+        self.assertEqual(membership.user, new_user)
+
+        executor.loader.build_graph()
+        executor.migrate(migrate_from)
+
+        # user is still a member
+        old_group.refresh_from_db()
+        self.assertQuerySetEqual(old_group.users.all(), [old_user])
+
+    def test_user_group_roles(self) -> None:
+        """Test converting user-group m2m to through model."""
+        migrate_from = [("db", "0136_add_groupmembership")]
+        migrate_to = [("db", "0137_add_groupmembership_role")]
+
+        executor = MigrationExecutor(
+            connection, progress_callback=_migrate_check_constraints
+        )
+        executor.migrate(migrate_from)
+        old_apps = executor.loader.project_state(migrate_from).apps
+        OldScope = old_apps.get_model("db", "Scope")
+        OldGroup = old_apps.get_model("db", "Group")
+        old_user = self.get_test_user_for_apps(old_apps)
+        old_scope = OldScope.objects.create(name="scope")
+        old_group = OldGroup.objects.create(scope=old_scope, name="group")
+        old_group.users.add(old_user)
+
+        executor.loader.build_graph()
+        executor.migrate(migrate_to)
+
+        new_apps = executor.loader.project_state(migrate_to).apps
+        NewGroup = new_apps.get_model("db", "Group")
+        new_user = self.get_test_user_for_apps(new_apps)
+        new_group = NewGroup.objects.get(name="group")
+        membership = new_group.membership.first()
+        self.assertEqual(membership.group, new_group)
+        self.assertEqual(membership.user, new_user)
+        self.assertEqual(membership.role, Group.Roles.MEMBER)
+
+        executor.loader.build_graph()
+        executor.migrate(migrate_from)
+
+        # user is still a member
+        old_group.refresh_from_db()
+        self.assertQuerySetEqual(old_group.users.all(), [old_user])
