@@ -44,12 +44,9 @@ from debusine.db.models.work_requests import (
     WorkRequest,
     WorkflowTemplate,
 )
+from debusine.db.models.worker_pools import ScopeWorkerPool, WorkerPool
 from debusine.db.models.workers import Worker
-from debusine.db.models.workspaces import (
-    DEFAULT_WORKSPACE_NAME,
-    Workspace,
-    default_workspace,
-)
+from debusine.db.models.workspaces import Workspace, default_workspace
 
 __all__ = [
     "Artifact",
@@ -60,7 +57,6 @@ __all__ = [
     "CollectionItem",
     "CollectionItemMatchConstraint",
     "DEFAULT_FILE_STORE_NAME",
-    "DEFAULT_WORKSPACE_NAME",
     "File",
     "FileInArtifact",
     "FileInStore",
@@ -71,11 +67,13 @@ __all__ = [
     "Identity",
     "NotificationChannel",
     "Scope",
+    "ScopeWorkerPool",
     "SYSTEM_USER_NAME",
     "TaskDatabase",
     "Token",
     "User",
     "Worker",
+    "WorkerPool",
     "WorkflowTemplate",
     "WorkRequest",
     "Workspace",
