@@ -164,7 +164,7 @@ def permission_check(
 
 
 def permission_filter(
-    f: Callable[[QS, PermissionUser], QS]
+    f: Callable[[QS, PermissionUser], QS],
 ) -> Callable[[QS, PermissionUser], QS]:
     """
     Implement common elements of permission filtering predicates.
@@ -220,14 +220,14 @@ def get_resource_scope(obj: M) -> Optional["Scope"]:
     :returns: None if the resource does not have a scope
     :raises NotImplementedError: for resources not currently supported
     """
-    from debusine.db.models import ArtifactRelation, Group, Scope, User
+    from debusine.db.models import ArtifactRelation, Scope, User
 
     match obj:
         case ArtifactRelation():
             return obj.artifact.workspace.scope
         case Scope():
             return obj
-        case User() | Group():
+        case User():
             return None
         case _:
             if hasattr(obj, "scope"):
