@@ -39,7 +39,7 @@ from debusine.test.django import (
     TestCase,
     override_permission,
 )
-from debusine.test.utils import data_generator
+from debusine.test.test_utils import data_generator
 
 
 class ArtifactManagerTests(TestCase):
