@@ -9,11 +9,12 @@
 
 """Unit tests for the worker models."""
 
+import datetime
 from typing import ClassVar
 
 from django.utils import timezone
 
-from debusine.db.models import Token, WorkRequest, Worker
+from debusine.db.models import Token, WorkRequest, Worker, WorkerPool
 from debusine.db.models.workers import WorkerManager
 from debusine.tasks.models import WorkerType
 from debusine.test.django import TestCase
@@ -127,6 +128,32 @@ class WorkerManagerTests(TestCase):
             Worker.objects.waiting_for_work_request(), [worker_enabled]
         )
 
+    def test_waiting_for_work_request_static_first(self) -> None:
+        """Ensure waiting_for_work_request() returns static workers first."""
+        worker_static = Worker.objects.create_with_fqdn(
+            "worker-static", Token.objects.create(enabled=True)
+        )
+
+        worker_cloud = Worker.objects.create_with_fqdn(
+            "worker-cloud", Token.objects.create(enabled=True)
+        )
+        worker_cloud.worker_pool = WorkerPool.objects.create(
+            name="test",
+            provider_account=(
+                self.playground.create_cloud_provider_account_asset()
+            ),
+            registered_at=timezone.now(),
+        )
+        worker_cloud.save()
+
+        worker_cloud.mark_connected()
+        worker_static.mark_connected()
+
+        self.assertQuerySetEqual(
+            Worker.objects.waiting_for_work_request(),
+            [worker_static, worker_cloud],
+        )
+
     def test_create_with_fqdn_new_fqdn(self) -> None:
         """WorkerManager.create_with_fqdn() return a worker."""
         token = Token.objects.create()
@@ -158,6 +185,35 @@ class WorkerManagerTests(TestCase):
         self.assertEqual(worker.worker_type, WorkerType.EXTERNAL)
         self.assertIsNotNone(worker.pk)
 
+    def test_create_pool_members(self) -> None:
+        worker_pool = self.playground.create_worker_pool(name="pool")
+        # 1 existing worker in the middle of our scheme
+        Worker.objects.create_with_fqdn(
+            "pool-002", token=Token.objects.create()
+        )
+
+        before = timezone.now()
+        Worker.objects.create_pool_members(worker_pool, 3)
+        after = timezone.now()
+
+        self.assertQuerySetEqual(
+            Worker.objects.filter(
+                worker_pool=worker_pool,
+                activation_token__isnull=False,
+                activation_token__expire_at__gte=(
+                    before + datetime.timedelta(minutes=15)
+                ),
+                activation_token__expire_at__lte=(
+                    after + datetime.timedelta(minutes=15)
+                ),
+                activation_token__enabled=True,
+                token__isnull=True,
+            )
+            .order_by("name")
+            .values_list("name", flat=True),
+            ["pool-001", "pool-003", "pool-004"],
+        )
+
     def test_get_or_create_celery(self) -> None:
         """WorkerManager.get_or_create_celery returns a Celery worker."""
         worker = Worker.objects.get_or_create_celery()
@@ -209,6 +265,73 @@ class WorkerManagerTests(TestCase):
         """WorkerManager.get_worker_or_none() return None."""
         self.assertIsNone(Worker.objects.get_worker_or_none('does-not-exist'))
 
+    def test_with_idle_time_no_work_requests_not_connected(self) -> None:
+        """Test idle_time with no work requests assigned and never connected."""
+        worker = Worker.objects.create_with_fqdn(
+            'worker-a', Token.objects.create(enabled=True)
+        )
+        worker.registered_at = timezone.now() - datetime.timedelta(days=1)
+        worker.save()
+
+        idle_time = (
+            Worker.objects.with_idle_time().get(pk=worker.pk)
+        ).idle_time  # type: ignore[attr-defined]
+        self.assertGreaterEqual(idle_time, 86400)
+        self.assertLessEqual(idle_time, 86400 + 3600)
+
+    def test_with_idle_time_no_work_requests_connected(self) -> None:
+        """Compute idle_time with no work requests assigned and connected."""
+        worker = Worker.objects.create_with_fqdn(
+            'worker-a', Token.objects.create(enabled=True)
+        )
+        worker.registered_at = timezone.now() - datetime.timedelta(days=2)
+        worker.instance_created_at = timezone.now() - datetime.timedelta(days=1)
+        worker.save()
+
+        idle_time = (
+            Worker.objects.with_idle_time().get(pk=worker.pk)
+        ).idle_time  # type: ignore[attr-defined]
+        self.assertGreaterEqual(idle_time, 86400)
+        self.assertLessEqual(idle_time, 86400 + 3600)
+
+    def test_with_idle_time_running_task(self) -> None:
+        """Compute idle_time with a running task."""
+        worker = Worker.objects.create_with_fqdn(
+            'worker-a', Token.objects.create(enabled=True)
+        )
+        worker.registered_at = timezone.now() - datetime.timedelta(days=2)
+        worker.instance_created_at = timezone.now() - datetime.timedelta(days=1)
+        worker.save()
+        work_request = self.playground.create_work_request(worker=worker)
+        work_request.mark_running()
+        worker.refresh_from_db()
+        self.assertTrue(worker.is_busy())
+
+        idle_time = (
+            Worker.objects.with_idle_time().get(pk=worker.pk)
+        ).idle_time  # type: ignore[attr-defined]
+        self.assertGreaterEqual(idle_time, 0)
+
+    def test_with_idle_time_completed_task(self) -> None:
+        """Compute idle_time with a running task."""
+        worker = Worker.objects.create_with_fqdn(
+            'worker-a', Token.objects.create(enabled=True)
+        )
+        worker.registered_at = timezone.now() - datetime.timedelta(days=2)
+        worker.instance_created_at = timezone.now() - datetime.timedelta(days=1)
+        worker.save()
+        work_request = self.playground.create_work_request(worker=worker)
+        work_request.mark_running()
+        work_request.mark_completed(WorkRequest.Results.SUCCESS)
+        work_request.completed_at = timezone.now() - datetime.timedelta(hours=6)
+        work_request.save()
+
+        idle_time = (
+            Worker.objects.with_idle_time().get(pk=worker.pk)
+        ).idle_time  # type: ignore[attr-defined]
+        self.assertGreaterEqual(idle_time, 6 * 3600)
+        self.assertLessEqual(idle_time, 7 * 3600)
+
 
 class WorkerTests(TestCase):
     """Tests for the Worker model."""
