@@ -14,12 +14,25 @@ import hashlib
 from typing import Any, Optional, TYPE_CHECKING
 
 from django.db import IntegrityError, models, transaction
-from django.db.models import CheckConstraint, Count, F, JSONField, Q, QuerySet
+from django.db.models import (
+    CheckConstraint,
+    Count,
+    Exists,
+    F,
+    JSONField,
+    Max,
+    OuterRef,
+    Q,
+    QuerySet,
+)
+from django.db.models.expressions import Case, When
+from django.db.models.functions import Extract, Greatest, Now
 from django.utils import timezone
 from django.utils.text import slugify
 
 from debusine.db.models import WorkRequest
 from debusine.db.models.auth import Token
+from debusine.db.models.worker_pools import WorkerPool
 from debusine.tasks.models import WorkerType
 
 if TYPE_CHECKING:
@@ -33,9 +46,7 @@ class WorkerManager(models.Manager["Worker"]):
 
     def connected(self) -> QuerySet["Worker"]:
         """Return connected workers."""
-        return Worker.objects.filter(connected_at__isnull=False).order_by(
-            'connected_at'
-        )
+        return self.filter(connected_at__isnull=False).order_by('connected_at')
 
     def waiting_for_work_request(self) -> QuerySet["Worker"]:
         """
@@ -60,8 +71,8 @@ class WorkerManager(models.Manager["Worker"]):
             ),
         )
         workers = (
-            Worker.objects.filter(connected_at__isnull=False)
-            .order_by('connected_at')
+            self.filter(connected_at__isnull=False)
+            .order_by(F('worker_pool').asc(nulls_first=True), 'connected_at')
             .annotate(count_running=running_work_request_count)
             .filter(count_running__lt=F("concurrency"))
             .filter(Q(worker_type=WorkerType.CELERY) | Q(token__enabled=True))
@@ -69,6 +80,34 @@ class WorkerManager(models.Manager["Worker"]):
 
         return workers
 
+    def with_idle_time(self) -> QuerySet["Worker"]:
+        """
+        Annotate workers with `idle_time`.
+
+        `Worker.idle_time` will be 0 for workers currently assigned a running
+        work request, or the number of seconds the worker has been spending
+        without a running work request assigned.
+        """
+        tasks = WorkRequest.objects.filter(worker=OuterRef("pk"))
+        return self.annotate(
+            idle_time=Case(
+                When(
+                    Exists(tasks.filter(status=WorkRequest.Statuses.RUNNING)),
+                    then=0,
+                ),
+                When(
+                    Exists(tasks),
+                    then=Extract(
+                        Now() - Max(tasks.values("completed_at")), "epoch"
+                    ),
+                ),
+                default=Extract(
+                    Now() - Greatest("registered_at", "instance_created_at"),
+                    "epoch",
+                ),
+            )
+        )
+
     @staticmethod
     def _generate_unique_name(name: str, counter: int) -> str:
         """Return name slugified adding "-counter" if counter != 1."""
@@ -79,38 +118,66 @@ class WorkerManager(models.Manager["Worker"]):
 
         return new_name
 
-    @classmethod
     def create_with_fqdn(
-        cls,
+        self,
         fqdn: str,
         token: Token,
         worker_type: WorkerType = WorkerType.EXTERNAL,
+        worker_pool: WorkerPool | None = None,
     ) -> "Worker":
         """Return a new Worker with its name based on fqdn, with token."""
         counter = 1
 
         while True:
-            name = cls._generate_unique_name(fqdn, counter)
+            name = self._generate_unique_name(fqdn, counter)
             try:
                 with transaction.atomic():
-                    return Worker.objects.create(
+                    return self.create(
                         name=name,
                         token=token,
                         worker_type=worker_type,
                         registered_at=timezone.now(),
+                        worker_pool=worker_pool,
                     )
             except IntegrityError:
                 counter += 1
 
-    @classmethod
-    def get_or_create_celery(cls) -> "Worker":
+    def create_pool_members(
+        self,
+        worker_pool: WorkerPool,
+        count: int,
+    ) -> None:
+        """
+        Create count new External Workers in worker_pool.
+
+        Use throw-away activation tokens; when workers start, they'll
+        exchange their activation tokens for full worker tokens.
+        """
+        created = 0
+        index = 1
+        while created < count:
+            with transaction.atomic():
+                try:
+                    self.create(
+                        name=f"{worker_pool.name}-{index:03}",
+                        activation_token=(
+                            Token.objects.create_worker_activation()
+                        ),
+                        worker_type=WorkerType.EXTERNAL,
+                        worker_pool=worker_pool,
+                        registered_at=timezone.now(),
+                    )
+                    created += 1
+                except IntegrityError:
+                    pass
+            index += 1
+
+    def get_or_create_celery(self) -> "Worker":
         """Return a new Worker representing the Celery task queue."""
         try:
-            return Worker.objects.get(
-                name="celery", worker_type=WorkerType.CELERY
-            )
+            return self.get(name="celery", worker_type=WorkerType.CELERY)
         except Worker.DoesNotExist:
-            return Worker.objects.create(
+            return self.create(
                 name="celery",
                 worker_type=WorkerType.CELERY,
                 registered_at=timezone.now(),
@@ -122,7 +189,7 @@ class WorkerManager(models.Manager["Worker"]):
         """Return a Worker identified by its associated secret token."""
         try:
             token_hash = hashlib.sha256(token_key.encode()).hexdigest()
-            return Worker.objects.get(token__hash=token_hash)
+            return self.get(token__hash=token_hash)
         except Worker.DoesNotExist:
             return None
 
@@ -143,11 +210,23 @@ class Worker(models.Model):
     )
     registered_at = models.DateTimeField()
     connected_at = models.DateTimeField(blank=True, null=True)
+    instance_created_at = models.DateTimeField(blank=True, null=True)
+
     # This is the token used by the Worker to authenticate
     # Users have their own tokens - this is specific to a single worker.
     token = models.OneToOneField(
         Token, null=True, on_delete=models.PROTECT, related_name="worker"
     )
+    # This is used to grant workers the ability to bootstrap authentication
+    # for themselves, in situations where their provisioning data may be
+    # revealed to untrusted code later.  The activation token will be
+    # deleted once it has been used.
+    activation_token = models.OneToOneField(
+        Token,
+        null=True,
+        on_delete=models.SET_NULL,
+        related_name="activating_worker",
+    )
     static_metadata = JSONField(default=dict, blank=True)
     dynamic_metadata = JSONField(default=dict, blank=True)
 
@@ -166,12 +245,19 @@ class Worker(models.Model):
         help_text="Number of tasks this worker can run simultaneously",
     )
 
+    worker_pool = models.ForeignKey(
+        WorkerPool, blank=True, null=True, on_delete=models.PROTECT
+    )
+    worker_pool_data = JSONField(null=True, blank=True)
+
     class Meta(TypedModelMeta):
         constraints = [
             # Non-Celery workers must have a token.
             CheckConstraint(
                 name="%(app_label)s_%(class)s_celery_or_token",
-                check=Q(worker_type=WorkerType.CELERY) | Q(token__isnull=False),
+                check=Q(worker_type=WorkerType.CELERY)
+                | Q(activation_token__isnull=False)
+                | Q(token__isnull=False),
             )
         ]
 
