@@ -331,13 +331,11 @@ class DeleteWorkspaces:
         self.workspaces.delete()
 
 
-DEFAULT_WORKSPACE_NAME = "System"
-
-
 def default_workspace() -> "Workspace":
     """Return the default Workspace."""
     return Workspace.objects.get(
-        scope__name=settings.DEBUSINE_DEFAULT_SCOPE, name=DEFAULT_WORKSPACE_NAME
+        scope__name=settings.DEBUSINE_DEFAULT_SCOPE,
+        name=settings.DEBUSINE_DEFAULT_WORKSPACE,
     )
 
 
