@@ -41,6 +41,11 @@ from debusine.assets import (
     AssetCategory,
     BaseAssetDataModel,
     CloudProviderAccountData,
+    CloudProvidersType,
+    DummyProviderAccountData,
+    HetznerProviderAccountConfiguration,
+    HetznerProviderAccountCredentials,
+    HetznerProviderAccountData,
     KeyPurpose,
     SigningKeyData,
 )
@@ -54,7 +59,6 @@ from debusine.db.models import (
     Collection,
     CollectionItem,
     DEFAULT_FILE_STORE_NAME,
-    DEFAULT_WORKSPACE_NAME,
     File,
     FileInArtifact,
     FileStore,
@@ -65,6 +69,7 @@ from debusine.db.models import (
     User,
     WorkRequest,
     Worker,
+    WorkerPool,
     WorkflowTemplate,
     Workspace,
 )
@@ -76,6 +81,13 @@ from debusine.db.models.permissions import (
 from debusine.db.tests.utils import _calculate_hash_from_data
 from debusine.server.collections.lookup import lookup_single
 from debusine.server.file_backend.interface import FileBackendInterface
+from debusine.server.worker_pools import (
+    AWSEC2WorkerPoolSpecification,
+    DummyWorkerPoolSpecification,
+    HetznerCloudWorkerPoolSpecification,
+    WorkerPoolLimits,
+    WorkerPoolSpecifications,
+)
 from debusine.server.workflows.models import (
     BaseWorkflowData,
     WorkRequestWorkflowData,
@@ -132,7 +144,7 @@ class Playground(ArtifactPlayground):
     def __init__(
         self,
         default_file_store_name: str = DEFAULT_FILE_STORE_NAME,
-        default_workspace_name: str = DEFAULT_WORKSPACE_NAME,
+        default_workspace_name: str = settings.DEBUSINE_DEFAULT_WORKSPACE,
         default_username: str = "playground",
         default_user_password: str | None = None,
         default_user_email: str = "playground@example.org",
@@ -271,6 +283,13 @@ class Playground(ArtifactPlayground):
         group.assign_role(resource, role)
         return group
 
+    @context.disable_permission_checks()
+    def add_user(
+        self, group: Group, user: User, role: Group.Roles = Group.Roles.MEMBER
+    ) -> None:
+        """Add a user to a group."""
+        group.add_user(user, role)
+
     @context.disable_permission_checks()
     def create_bare_token(self, enabled: bool = True, **kwargs: Any) -> Token:
         """
@@ -307,6 +326,28 @@ class Playground(ArtifactPlayground):
             token.disable()
         return token
 
+    @context.disable_permission_checks()
+    def create_worker_activation_token(
+        self, worker: Worker | None = None, enabled: bool = True, **kwargs: Any
+    ) -> Token:
+        """
+        Return a worker activation token.
+
+        Optionally create the worker if none is supplied.
+        """
+        token = Token.objects.create(**kwargs)
+
+        if worker is None:
+            worker = self.create_worker()
+        worker.activation_token = token
+        worker.save()
+
+        if enabled:
+            token.enable()
+        else:
+            token.disable()
+        return token
+
     @context.disable_permission_checks()
     def create_user_token(
         self, user: User | None = None, enabled: bool = True, **kwargs: Any
@@ -508,13 +549,21 @@ class Playground(ArtifactPlayground):
         self,
         worker_type: WorkerType = WorkerType.EXTERNAL,
         extra_dynamic_metadata: dict[str, Any] | None = None,
+        worker_pool: WorkerPool | None = None,
     ) -> Worker:
         """Return a new Worker."""
-        token = self.create_bare_token()
-        worker = Worker.objects.create_with_fqdn(
-            "computer.lan", worker_type=worker_type, token=token
-        )
-        self.create_worker_token(worker=worker)
+        if worker_pool is not None:
+            Worker.objects.create_pool_members(worker_pool=worker_pool, count=1)
+            worker = Worker.objects.filter(
+                worker_type=worker_type,
+                worker_pool=worker_pool,
+            ).latest("registered_at")
+        else:
+            worker = Worker.objects.create_with_fqdn(
+                "computer.lan",
+                worker_type=worker_type,
+                token=self.create_bare_token(),
+            )
 
         dynamic_metadata = {
             "system:cpu_cores": 4,
@@ -527,8 +576,64 @@ class Playground(ArtifactPlayground):
 
         worker.set_dynamic_metadata(dynamic_metadata)
 
+        if worker_pool:
+            worker.instance_created_at = timezone.now()
+            worker.save()
+
         return worker
 
+    @context.disable_permission_checks()
+    def create_worker_pool(
+        self,
+        name: str = "test",
+        enabled: bool = True,
+        architectures: list[str] | None = None,
+        tags: list[str] | None = None,
+        provider_account: Asset | None = None,
+        specifications: WorkerPoolSpecifications | None = None,
+        instance_wide: bool = True,
+        ephemeral: bool = False,
+        limits: WorkerPoolLimits | None = None,
+    ) -> WorkerPool:
+        """Return a new WorkerPool."""
+        if architectures is None:
+            architectures = ["amd64", "i386"]
+        if tags is None:
+            tags = []
+        if provider_account is None:
+            provider_account = self.create_cloud_provider_account_asset()
+        if specifications is None:
+            provider_type = provider_account.data["provider_type"]
+            match provider_type:
+                case CloudProvidersType.DUMMY:
+                    specifications = DummyWorkerPoolSpecification()
+                case CloudProvidersType.AWS:
+                    specifications = AWSEC2WorkerPoolSpecification(
+                        launch_templates=[]
+                    )
+                case CloudProvidersType.HETZNER:
+                    specifications = HetznerCloudWorkerPoolSpecification(
+                        server_type="cx22",
+                        image_name="debian-12",
+                    )
+                case _:
+                    raise NotImplementedError(f"No support for {provider_type}")
+        if limits is None:
+            limits = WorkerPoolLimits()
+        pool = WorkerPool.objects.create(
+            name=name,
+            provider_account=provider_account,
+            enabled=enabled,
+            architectures=architectures,
+            tags=tags,
+            specifications=specifications.dict(),
+            instance_wide=instance_wide,
+            ephemeral=ephemeral,
+            limits=limits.dict(),
+            registered_at=timezone.now(),
+        )
+        return pool
+
     @context.disable_permission_checks()
     def create_file(self, contents: bytes = b"test") -> File:
         """
@@ -619,7 +724,7 @@ class Playground(ArtifactPlayground):
         - files_contents: Dict[str, bytes] (paths and test data)
         """
         # Import here to avoid a circular loop
-        from debusine.test.utils import data_generator
+        from debusine.test.test_utils import data_generator
 
         if skip_add_files_in_store and not create_files:
             raise ValueError(
@@ -1058,21 +1163,40 @@ class Playground(ArtifactPlayground):
     def create_cloud_provider_account_asset(
         self,
         data: CloudProviderAccountData | None = None,
+        cloud_provider: CloudProvidersType | None = None,
+        name: str | None = None,
         workspace: Workspace | None = None,
         created_by: User | None = None,
         created_by_work_request: WorkRequest | None = None,
     ) -> Asset:
         """Create a debusine:cloud-provider-account asset."""
         if data is None:
-            data = AWSProviderAccountData(
-                name="test",
-                configuration=AWSProviderAccountConfiguration(
-                    region_name="test-region"
-                ),
-                credentials=AWSProviderAccountCredentials(
-                    access_key_id="access-key", secret_access_key="secret-key"
-                ),
-            )
+            if name is None:
+                name = "test"
+            match cloud_provider:
+                case CloudProvidersType.AWS:
+                    data = AWSProviderAccountData(
+                        name=name,
+                        configuration=AWSProviderAccountConfiguration(
+                            region_name="test-region"
+                        ),
+                        credentials=AWSProviderAccountCredentials(
+                            access_key_id="access-key",
+                            secret_access_key="secret-key",
+                        ),
+                    )
+                case CloudProvidersType.HETZNER:
+                    data = HetznerProviderAccountData(
+                        name=name,
+                        configuration=HetznerProviderAccountConfiguration(
+                            region_name="test-region",
+                        ),
+                        credentials=HetznerProviderAccountCredentials(
+                            api_token="api-token",
+                        ),
+                    )
+                case _:
+                    data = DummyProviderAccountData(name=name)
         return self.create_asset(
             category=AssetCategory.CLOUD_PROVIDER_ACCOUNT,
             data=data,
