@@ -25,7 +25,7 @@ from django.db import transaction
 from debusine.db.models import Group, Scope, User
 from debusine.db.models.scopes import ScopeRole
 from debusine.django.management.debusine_base_command import DebusineBaseCommand
-from debusine.server.management.utils import Groups, Users
+from debusine.server.management.management_utils import Groups, Users, get_scope
 
 
 def print_validation_error(error: ValidationError, file: OutputWrapper) -> None:
@@ -120,13 +120,6 @@ class Command(DebusineBaseCommand):
             help="set members to listed users",
         )
 
-    def get_scope(self, scope_name: str) -> Scope:
-        """Lookup a scope by name."""
-        try:
-            return Scope.objects.get(name=scope_name)
-        except Scope.DoesNotExist:
-            raise CommandError(f"Scope {scope_name!r} not found", returncode=3)
-
     def get_scope_and_group_name(self, scope_group: str) -> tuple[Scope, str]:
         """Lookup a scopename/groupname string."""
         if "/" not in scope_group:
@@ -136,7 +129,7 @@ class Command(DebusineBaseCommand):
                 returncode=3,
             )
         scope_name, group_name = scope_group.split("/", 1)
-        return self.get_scope(scope_name), group_name
+        return get_scope(scope_name), group_name
 
     def get_scope_and_group(self, scope_group: str) -> tuple[Scope, Group]:
         """Lookup a scopename/groupname string."""
@@ -187,7 +180,7 @@ class Command(DebusineBaseCommand):
 
     def handle_list(self, **options: Any) -> NoReturn:
         """List groups in a scope."""
-        scope = self.get_scope(options["scope"])
+        scope = get_scope(options["scope"])
         groups = Group.objects.filter(scope=scope)
         Groups(options["yaml"]).print(groups, self.stdout)
         raise SystemExit(0)
@@ -259,11 +252,11 @@ class Command(DebusineBaseCommand):
             if usernames := options["add"]:
                 change_requested = True
                 for user in self.get_users(usernames):
-                    group.users.add(user)
+                    group.add_user(user)
             if usernames := options["remove"]:
                 change_requested = True
                 for user in self.get_users(usernames):
-                    group.users.remove(user)
+                    group.remove_user(user)
 
         if not change_requested:
             # List users
