@@ -34,6 +34,7 @@ from debusine.db.models import (
     Scope,
 )
 from debusine.django.management.debusine_base_command import DebusineBaseCommand
+from debusine.server.management.management_utils import get_scope
 
 
 class Command(DebusineBaseCommand):
@@ -163,13 +164,6 @@ class Command(DebusineBaseCommand):
         show = subparsers.add_parser("show", help="Show a scope")
         show.add_argument("scope", help="Scope to show")
 
-    def get_scope(self, name: str) -> Scope:
-        """Lookup a scope by name."""
-        try:
-            return Scope.objects.get(name=name)
-        except Scope.DoesNotExist:
-            raise CommandError(f"Scope {name!r} not found", returncode=3)
-
     def get_file_store(self, name: str) -> FileStore:
         """Look up a file store by name."""
         try:
@@ -251,7 +245,7 @@ class Command(DebusineBaseCommand):
         self, *, scope: str, name: str, **options: Any
     ) -> NoReturn:
         """Rename a scope."""
-        s = self.get_scope(scope)
+        s = get_scope(scope)
 
         if name == s.name:
             raise SystemExit(0)
@@ -286,7 +280,7 @@ class Command(DebusineBaseCommand):
         **options: Any,
     ) -> NoReturn:
         """Add a file store to a scope."""
-        scope = self.get_scope(scope_name)
+        scope = get_scope(scope_name)
         file_store = self.get_file_store(file_store_name)
         through_defaults = {
             "upload_priority": upload_priority or None,
@@ -318,7 +312,7 @@ class Command(DebusineBaseCommand):
         **options: Any,
     ) -> NoReturn:
         """Edit properties of a file store in a scope."""
-        scope = self.get_scope(scope_name)
+        scope = get_scope(scope_name)
         try:
             file_store_extra = scope.filestoreinscope_set.get(
                 file_store__name=file_store_name
@@ -353,7 +347,7 @@ class Command(DebusineBaseCommand):
         self, scope_name: str, file_store_name: str, **options: Any
     ) -> NoReturn:
         """Remove a file store from a scope."""
-        scope = self.get_scope(scope_name)
+        scope = get_scope(scope_name)
         try:
             file_store = scope.file_stores.get(name=file_store_name)
         except FileStore.DoesNotExist:
@@ -381,7 +375,7 @@ class Command(DebusineBaseCommand):
 
     def handle_show(self, scope: str, **options: Any) -> NoReturn:
         """Show a scope."""
-        s = self.get_scope(scope)
+        s = get_scope(scope)
 
         # TODO: This layout is a bit odd: we're trying to fit everything
         # into a single table despite the true structure being nested.  It
