@@ -33,6 +33,7 @@ from debusine.db.models import (
     FileInStore,
     FileStore,
     Group,
+    Token,
     WorkRequest,
     WorkflowTemplate,
     default_file_store,
@@ -48,12 +49,13 @@ from debusine.server.collections import DebianEnvironmentsManager
 from debusine.server.management.commands.delete_expired import (
     DeleteExpiredArtifacts,
     DeleteExpiredEphemeralGroups,
+    DeleteExpiredTokens,
     DeleteExpiredWorkRequests,
     DeleteExpiredWorkspaces,
     DeleteOperation,
 )
 from debusine.test.django import TestCase, TransactionTestCase
-from debusine.test.utils import tomorrow
+from debusine.test.test_utils import tomorrow
 
 
 class DeleteExpiredCommandTests(TestCase):
@@ -141,11 +143,16 @@ class DeleteExpiredCommandTests(TestCase):
                     name="ws", expiration_delay=timedelta(days=7)
                 )
 
+            self.playground.create_worker_activation_token(
+                expire_at=timezone.now() - timedelta(days=1)
+            )
+
         num_artifacts = Artifact.objects.count()
         num_artifact_relations = ArtifactRelation.objects.count()
         num_files_in_store = FileInStore.objects.all().count()
         num_work_requests = WorkRequest.objects.all().count()
         num_collections = Collection.objects.all().count()
+        num_tokens = Token.objects.count()
 
         stdout, stderr, retval = call_command(
             "delete_expired", "--dry-run", verbosity=2
@@ -160,6 +167,7 @@ class DeleteExpiredCommandTests(TestCase):
             )
             + "There were no unused ephemeral groups\n"
             + "Deleting 1 expired workspaces\n"
+            + "Deleting 1 expired tokens\n"
             + "dry-run mode: no changes were made\n",
         )
 
@@ -176,6 +184,9 @@ class DeleteExpiredCommandTests(TestCase):
         self.assertEqual(WorkRequest.objects.all().count(), num_work_requests)
         self.assertEqual(Collection.objects.all().count(), num_collections)
 
+        # Tokens didn't get deleted
+        self.assertEqual(Token.objects.count(), num_tokens)
+
     def test_delete_expired_dry_run(self) -> None:
         """Test --dry-run without verbose does not write to stdout."""
         stdout, stderr, retval = call_command("delete_expired", "--dry-run")
@@ -212,8 +223,10 @@ class DeleteExpiredCommandTests(TestCase):
             )
         self.assertEqual(WorkRequest.objects.count(), 1)
         num_collections = Collection.objects.count()
-
         group = self.playground.create_group(name="test", ephemeral=True)
+        token = self.playground.create_worker_activation_token(
+            expire_at=timezone.now() - timedelta(days=1)
+        )
 
         stdout, stderr, retval = call_command("delete_expired", verbosity=2)
 
@@ -222,13 +235,15 @@ class DeleteExpiredCommandTests(TestCase):
             _format_deleted_work_requests([work_request_1], [collection_1])
             + _format_deleted_artifacts({artifact_id_1, artifact_id_2})
             + "Deleting 1 unused ephemeral groups\n"
-            + "Deleting 1 expired workspaces\n",
+            + "Deleting 1 expired workspaces\n"
+            + "Deleting 1 expired tokens\n",
         )
         self.assertEqual(Artifact.objects.count(), 0)
         self.assertEqual(ArtifactRelation.objects.count(), 0)
         self.assertEqual(WorkRequest.objects.count(), 0)
         self.assertEqual(Collection.objects.count(), num_collections - 1)
         self.assertQuerySetEqual(Group.objects.filter(pk=group.pk), [])
+        self.assertQuerySetEqual(Token.objects.filter(pk=token.pk), [])
 
     def test_delete_expired_verbose_nothing_deleted(self) -> None:
         """Test delete_expired verbose: print no artifact expired."""
@@ -240,7 +255,8 @@ class DeleteExpiredCommandTests(TestCase):
             _format_deleted_work_requests([], [])
             + "There were no expired artifacts\n"
             + "There were no unused ephemeral groups\n"
-            + "There were no expired workspaces\n",
+            + "There were no expired workspaces\n"
+            + "There were no expired tokens\n",
         )
 
 
@@ -1241,6 +1257,97 @@ class DeleteExpiredWorkspacesTests(TestCase):
         self.assert_dry_run_does_not_delete()
 
 
+class DeleteExpiredTokensTest(TestCase):
+    """Tests for the DeleteExpiredTokens class."""
+
+    def setUp(self) -> None:
+        """Initialize test."""
+        self.out = io.StringIO()
+        self.err = io.StringIO()
+        self.operation = DeleteOperation(
+            out=self.out, err=self.err, dry_run=False
+        )
+        self.operation.initial_time = timezone.now()
+        self.delete_expired = DeleteExpiredTokens(self.operation)
+
+    @contextlib.contextmanager
+    def mock_perform_deletions(self) -> Iterator[mock.MagicMock]:
+        """Shortcut to mock perform_deletions."""
+        with mock.patch(
+            "debusine.server.management.commands.delete_expired"
+            ".DeleteExpiredTokens.perform_deletions"
+        ) as perform_deletions:
+            yield perform_deletions
+
+    @contextlib.contextmanager
+    def mock_verbose(self) -> Iterator[mock.MagicMock]:
+        """Shortcut to mock operation.verbose."""
+        with mock.patch(
+            "debusine.server.management.commands.delete_expired"
+            ".DeleteOperation.verbose"
+        ) as verbose:
+            yield verbose
+
+    def assert_dry_run_does_not_delete(self) -> None:
+        """Make sure that, with dry_run, perform_deletions is not called."""
+        old_dry_run = self.operation.dry_run
+        self.operation.dry_run = True
+        try:
+            with self.mock_perform_deletions() as perform_deletions:
+                self.delete_expired.run()
+            perform_deletions.assert_not_called()
+        finally:
+            self.operation.dry_run = old_dry_run
+
+    def test_no_expired(self) -> None:
+        """No expired tokens."""
+        with (
+            self.mock_perform_deletions() as perform_deletions,
+            self.mock_verbose() as verbose,
+        ):
+            self.delete_expired.run()
+
+        self.assertQuerySetEqual(self.delete_expired.tokens, [])
+        perform_deletions.assert_not_called()
+        verbose.assert_called_once_with("There were no expired tokens\n")
+
+    def test_one_expired(self) -> None:
+        """One unused token."""
+        token = self.playground.create_worker_activation_token(
+            expire_at=timezone.now() - timedelta(seconds=1)
+        )
+
+        with (
+            self.mock_perform_deletions() as perform_deletions,
+            self.mock_verbose() as verbose,
+        ):
+            self.delete_expired.run()
+
+        self.assertQuerySetEqual(self.delete_expired.tokens, [token])
+        perform_deletions.assert_called()
+        verbose.assert_called_once_with("Deleting 1 expired tokens\n")
+        self.assert_dry_run_does_not_delete()
+
+    def test_not_expired(self) -> None:
+        """Tokens in use."""
+        self.playground.create_bare_token()
+        self.playground.create_user_token()
+        self.playground.create_worker_token()
+        self.playground.create_worker_activation_token(
+            expire_at=timezone.now() + timedelta(days=1)
+        )
+
+        with (
+            self.mock_perform_deletions() as perform_deletions,
+            self.mock_verbose() as verbose,
+        ):
+            self.delete_expired.run()
+
+        self.assertQuerySetEqual(self.delete_expired.tokens, [])
+        perform_deletions.assert_not_called()
+        verbose.assert_called_once_with("There were no expired tokens\n")
+
+
 def _format_deleted_work_requests(
     work_requests: list[WorkRequest], collections: list[Collection]
 ) -> str:
