@@ -23,7 +23,6 @@ from debusine.artifacts.models import (
 from debusine.db.context import context
 from debusine.db.models import (
     ArtifactRelation,
-    Group,
     Scope,
     WorkRequest,
     WorkflowTemplate,
@@ -85,8 +84,8 @@ class WorkspaceCommandsTests(TabularOutputTests, TestCase):
         ):
             call_command("workspace", "create", "localtest/myws", "Owners-myws")
 
-        Group(scope=self.scope, name="Owners-myws").save()
-        Group(scope=self.scope, name="Owners-myws2").save()
+        self.playground.create_group("Owners-myws", scope=self.scope)
+        self.playground.create_group("Owners-myws2", scope=self.scope)
 
         # create/define, idempotent
         for i in (1, 2):
@@ -157,7 +156,7 @@ class WorkspaceCommandsTests(TabularOutputTests, TestCase):
 
     def test_rename_scenario(self) -> None:
         """Test rename command."""
-        Group(scope=self.scope, name="Owners-myws").save()
+        self.playground.create_group("Owners-myws", scope=self.scope)
         call_command("workspace", "create", "localtest/myws", "Owners-myws")
 
         # rename, with errors
@@ -216,7 +215,7 @@ class WorkspaceCommandsTests(TabularOutputTests, TestCase):
     def test_list(self) -> None:
         """Test list command."""
         # Setup
-        Group(scope=self.scope, name="Owners-myws").save()
+        self.playground.create_group("Owners-myws", scope=self.scope)
 
         call_command(
             "workspace", "create", "localtest/public", "Owners-myws", "--public"
@@ -283,9 +282,9 @@ class WorkspaceCommandsTests(TabularOutputTests, TestCase):
 
     def test_roles(self) -> None:
         """Test roles commands."""
-        Group(scope=self.scope, name="Admins").save()
-        Group(scope=self.scope, name="Employees").save()
-        Group(scope=self.scope, name="Contractors").save()
+        self.playground.create_group("Admins", scope=self.scope)
+        self.playground.create_group("Employees", scope=self.scope)
+        self.playground.create_group("Contractors", scope=self.scope)
 
         # fmt: off
         call_command("workspace", "create", "localtest/myws", "Admins")
