@@ -13,6 +13,7 @@ from collections.abc import Callable
 from copy import copy
 from typing import Any, Never, NoReturn, TYPE_CHECKING, TypeAlias
 
+from django.conf import settings
 from django.db.models import QuerySet
 from django.http import HttpRequest
 
@@ -37,7 +38,6 @@ from debusine.db.models import (
     Asset,
     Collection,
     CollectionItem,
-    DEFAULT_WORKSPACE_NAME,
     File,
     TaskDatabase,
     WorkRequest,
@@ -105,7 +105,9 @@ class WorkspaceInCurrentScopeField(SlugRelatedFieldBase[Workspace]):
     def _get_default_workspace(self) -> Workspace:
         """Get the default workspace."""
         try:
-            return self.get_queryset().get(name=DEFAULT_WORKSPACE_NAME)
+            return self.get_queryset().get(
+                name=settings.DEBUSINE_DEFAULT_WORKSPACE
+            )
         except Workspace.DoesNotExist:
             # The default workspace name might not exist in the current
             # scope.  If so, the client must provide a workspace.
