@@ -128,7 +128,7 @@ class WorkerStatus:
 
     @staticmethod
     def _count_task_by_worker_type(
-        tasks: dict[TaskTypes, TaskQueueSummary]
+        tasks: dict[TaskTypes, TaskQueueSummary],
     ) -> dict[WorkerType, TaskQueueSummary]:
         """Re-count queued tasks by worker type."""
         result: dict[WorkerType, TaskQueueSummary] = {
