@@ -36,7 +36,7 @@ from debusine.db.models import (
 from debusine.server.collections.debian_suite import DebianSuiteManager
 from debusine.server.tasks import BaseServerTask
 from debusine.server.tasks.models import APTMirrorData
-from debusine.tasks import TaskConfigError
+from debusine.tasks import DefaultDynamicData, TaskConfigError
 from debusine.tasks.models import BaseDynamicTaskData
 
 T = TypeVar("T", bound=Deb822)
@@ -89,7 +89,10 @@ def _run_and_log_errors(
         raise
 
 
-class APTMirror(BaseServerTask[APTMirrorData, BaseDynamicTaskData]):
+class APTMirror(
+    BaseServerTask[APTMirrorData, BaseDynamicTaskData],
+    DefaultDynamicData[APTMirrorData],
+):
     """Task that mirrors an external APT suite into a debusine collection."""
 
     TASK_VERSION = 1
