@@ -45,7 +45,7 @@ from debusine.server.scheduler import (
     schedule_for_worker,
 )
 from debusine.server.tasks import ServerNoop
-from debusine.server.tasks.wait import BaseWaitTask
+from debusine.server.tasks.tests.helpers import TestBaseWaitTask
 from debusine.server.tasks.wait.models import DelayData
 from debusine.server.workflows.models import WorkRequestWorkflowData
 from debusine.signing.tasks.models import GenerateKeyData
@@ -61,16 +61,13 @@ from debusine.tasks.models import (
     WorkerType,
 )
 from debusine.tasks.server import ArtifactInfo
-from debusine.tasks.tests.helper_mixin import (
-    FakeTaskDatabaseBase,
-    TestTaskMixin,
-)
+from debusine.tasks.tests.helper_mixin import FakeTaskDatabaseBase
 from debusine.test.django import (
     PlaygroundTestCase,
     TestCase,
     TransactionTestCase,
 )
-from debusine.test.utils import (
+from debusine.test.test_utils import (
     create_system_tarball_data,
     preserve_task_registry,
 )
@@ -386,16 +383,10 @@ class SchedulerTests(SchedulerTestCase, TestCase):
 
     def test_synchronization_points(self) -> None:
         """schedule() marks pending synchronization points as completed."""
-        user = self.playground.get_default_user()
         WorkRequest.objects.all().delete()
 
-        parent = WorkRequest.objects.create(
-            workspace=default_workspace(),
-            created_by=user,
-            status=WorkRequest.Statuses.RUNNING,
-            task_type=TaskTypes.WORKFLOW,
-            task_name="test",
-            task_data={},
+        parent = self.playground.create_workflow(
+            status=WorkRequest.Statuses.RUNNING
         )
 
         pending = [
@@ -461,12 +452,8 @@ class SchedulerTests(SchedulerTestCase, TestCase):
         status: WorkRequest.Statuses = WorkRequest.Statuses.PENDING,
     ) -> WorkRequest:
         """Create a Wait/Delay task in a workflow."""
-        user = self.playground.get_default_user()
-        parent = self.playground.create_work_request(
-            mark_running=True,
-            created_by=user,
-            task_type=TaskTypes.WORKFLOW,
-            task_name="test",
+        parent = self.playground.create_workflow(
+            status=WorkRequest.Statuses.RUNNING
         )
         return parent.create_child(
             task_name="delay",
@@ -517,20 +504,14 @@ class SchedulerTests(SchedulerTestCase, TestCase):
     def test_wait_other_task(self) -> None:
         """schedule() leaves non-Delay Wait tasks running."""
 
-        class WaitNoop(
-            TestTaskMixin, BaseWaitTask[BaseTaskData, BaseDynamicTaskData]
-        ):
+        class WaitNoop(TestBaseWaitTask[BaseTaskData, BaseDynamicTaskData]):
             TASK_VERSION = 1
 
             def _execute(self) -> bool:
                 raise NotImplementedError()
 
-        user = self.playground.get_default_user()
-        parent = self.playground.create_work_request(
-            mark_running=True,
-            created_by=user,
-            task_type=TaskTypes.WORKFLOW,
-            task_name="test",
+        parent = self.playground.create_workflow(
+            status=WorkRequest.Statuses.RUNNING
         )
         work_request = parent.create_child(
             task_name="waitnoop",
