@@ -12,6 +12,7 @@
 from datetime import datetime, timezone
 from typing import Any, ClassVar
 
+from django.conf import settings
 from django.test import RequestFactory, override_settings
 from django.urls import reverse
 from rest_framework.exceptions import ErrorDetail
@@ -25,7 +26,6 @@ from debusine.client.models import (
 from debusine.db.context import context
 from debusine.db.models import (
     Artifact,
-    DEFAULT_WORKSPACE_NAME,
     File,
     Token,
     WorkRequest,
@@ -47,7 +47,7 @@ from debusine.server.serializers import (
     WorkflowTemplateSerializer,
 )
 from debusine.tasks.models import OutputData, SbuildData, SbuildInput
-from debusine.test import utils
+from debusine.test import test_utils
 from debusine.test.django import TestCase
 
 
@@ -494,7 +494,7 @@ class ArtifactSerializerResponseTests(TestCase):
 
         download_path = self.artifact.get_absolute_url_download()
         download_url = f"http://{host}{download_path}?archive=tar.gz"
-        created_at = utils.date_time_to_isoformat_rest_framework(
+        created_at = test_utils.date_time_to_isoformat_rest_framework(
             self.artifact.created_at
         )
 
@@ -712,7 +712,7 @@ class WorkflowTemplateSerializerTests(TestCase):
         context.set_scope(self.playground.get_default_scope())
         data = {
             "name": "wt",
-            "workspace": DEFAULT_WORKSPACE_NAME,
+            "workspace": settings.DEBUSINE_DEFAULT_WORKSPACE,
             "task_name": "noop",
         }
 
@@ -729,7 +729,7 @@ class WorkflowTemplateSerializerTests(TestCase):
         context.set_scope(self.playground.get_default_scope())
         data = {
             "name": "wt",
-            "workspace": DEFAULT_WORKSPACE_NAME,
+            "workspace": settings.DEBUSINE_DEFAULT_WORKSPACE,
             "task_name": "nonexistent",
         }
 
