@@ -53,7 +53,10 @@ from debusine.server.views.base import (
     GetOrCreateAPIView,
     ListAPIViewBase,
 )
-from debusine.server.views.rest import IsTokenAuthenticated
+from debusine.server.views.rest import (
+    IsTokenUserAuthenticated,
+    IsWorkerAuthenticated,
+)
 from debusine.utils import parse_content_range_header
 
 logger = logging.getLogger(__name__)
@@ -306,7 +309,7 @@ class UploadFileView(BaseAPIView):
 
     parser_classes = [FileUploadParser]
     # TODO: This should be replaced by appropriate debusine permissions.
-    permission_classes = [IsTokenAuthenticated]
+    permission_classes = [IsTokenUserAuthenticated | IsWorkerAuthenticated]
 
     @staticmethod
     def _range_header(start: int, end: int) -> dict[str, str]:
