@@ -59,7 +59,7 @@ from debusine.test.django import (
     TestResponseType,
     override_permission,
 )
-from debusine.test.utils import date_time_to_isoformat_rest_framework
+from debusine.test.test_utils import date_time_to_isoformat_rest_framework
 
 
 class WorkRequestTestCase(TestCase):
@@ -340,6 +340,26 @@ class WorkRequestViewTests(WorkRequestTestCase):
         self.assertEqual(response.status_code, status.HTTP_200_OK)
         self.check_response_for_work_request(response, work_request)
 
+    def test_get_work_request_worker_activation_token(self) -> None:
+        """A worker activation token cannot get a work request."""
+        token = self.playground.create_worker_activation_token()
+        work_request = self.create_test_work_request()
+
+        response = self.client.get(
+            reverse(
+                "api:work-request-detail",
+                kwargs={"work_request_id": work_request.id},
+            ),
+            headers={"token": token.key},
+        )
+
+        self.assertResponseProblem(
+            response,
+            "Error",
+            detail_pattern="You do not have permission to perform this action.",
+            status_code=status.HTTP_403_FORBIDDEN,
+        )
+
     def test_get_work_request_not_found(self) -> None:
         """Return HTTP 404 if the WorkRequest id does not exist."""
         assert self.worker_01.token is not None
@@ -528,7 +548,9 @@ class WorkRequestViewTests(WorkRequestTestCase):
     @override_settings(DISABLE_AUTOMATIC_SCHEDULING=False)
     def test_post_success_workspace_default(self) -> None:
         """Client POST a WorkRequest without specifying a workspace."""
-        self.scenario.workspace_owners.users.add(self.scenario.user)
+        self.playground.add_user(
+            self.scenario.workspace_owners, self.scenario.user
+        )
         self.playground.create_debian_environment(codename="bookworm")
         self.verify_post_success()
 
@@ -537,7 +559,9 @@ class WorkRequestViewTests(WorkRequestTestCase):
         """Client POST a WorkRequest without specifying a workspace."""
         self.token = self.create_superuser_token()
         assert self.token.user is not None
-        self.scenario.workspace_owners.users.add(self.token.user)
+        self.playground.add_user(
+            self.scenario.workspace_owners, self.token.user
+        )
         self.playground.create_debian_environment(codename="bookworm")
         self.verify_post_success()
 
@@ -607,7 +631,9 @@ class WorkRequestViewTests(WorkRequestTestCase):
 
     def test_post_task_name_invalid(self) -> None:
         """Client POST a WorkRequest its task_name is invalid."""
-        self.scenario.workspace_owners.users.add(self.scenario.user)
+        self.playground.add_user(
+            self.scenario.workspace_owners, self.scenario.user
+        )
         work_request_serialized = {
             'task_name': 'bad-name',
             'task_data': {'foo': 'bar'},
@@ -623,7 +649,9 @@ class WorkRequestViewTests(WorkRequestTestCase):
 
     def test_post_non_worker_task(self) -> None:
         """Client POST a WorkRequest without enough rights for that type."""
-        self.scenario.workspace_owners.users.add(self.scenario.user)
+        self.playground.add_user(
+            self.scenario.workspace_owners, self.scenario.user
+        )
         work_request_serialized = {
             'task_name': 'servernoop',
             'task_data': {'foo': 'bar'},
@@ -641,7 +669,7 @@ class WorkRequestViewTests(WorkRequestTestCase):
         """Superusers can POST a server task."""
         token = self.create_superuser_token()
         assert token.user is not None
-        self.scenario.workspace_owners.users.add(token.user)
+        self.playground.add_user(self.scenario.workspace_owners, token.user)
 
         work_request_serialized = {
             'task_name': 'servernoop',
@@ -675,7 +703,9 @@ class WorkRequestViewTests(WorkRequestTestCase):
 
     def test_post_work_request_invalid_channel(self) -> None:
         """Post request with an invalid channel: returns HTTP 400 and error."""
-        self.scenario.workspace_owners.users.add(self.scenario.user)
+        self.playground.add_user(
+            self.scenario.workspace_owners, self.scenario.user
+        )
         channel = "non-existing"
         work_request_serialized = {
             "task_name": "sbuild",
@@ -730,7 +760,9 @@ class WorkRequestViewTests(WorkRequestTestCase):
 
         Returns HTTP 400 and error.
         """
-        self.scenario.workspace_owners.users.add(self.scenario.user)
+        self.playground.add_user(
+            self.scenario.workspace_owners, self.scenario.user
+        )
         work_request_serialized = {
             "task_name": "sbuild",
             "task_data": {
@@ -751,7 +783,9 @@ class WorkRequestViewTests(WorkRequestTestCase):
 
     def test_post_work_request_disallowed_action(self) -> None:
         """Action other than send-notification: returns HTTP 400 and error."""
-        self.scenario.workspace_owners.users.add(self.scenario.user)
+        self.playground.add_user(
+            self.scenario.workspace_owners, self.scenario.user
+        )
         work_request_serialized = {
             "task_name": "sbuild",
             "event_reactions": {
@@ -1348,13 +1382,10 @@ class WorkRequestUnblockViewTests(WorkRequestTestCase):
     def setUpTestData(cls) -> None:
         """Set up common data."""
         super().setUpTestData()
-        template = cls.playground.create_workflow_template("test", "noop")
-        cls.workflow = WorkRequest.objects.create_workflow(
-            template=template,
-            data={},
-            created_by=cls.playground.get_default_user(),
-            status=WorkRequest.Statuses.RUNNING,
+        cls.workflow = cls.playground.create_workflow(
+            status=WorkRequest.Statuses.RUNNING
         )
+
         cls.work_request = WorkRequest.objects.create_synchronization_point(
             parent=cls.workflow,
             step="test",
@@ -1428,7 +1459,9 @@ class WorkRequestUnblockViewTests(WorkRequestTestCase):
 
     def test_post_neither_notes_nor_action(self) -> None:
         """At least one of notes and action must be set."""
-        self.scenario.workspace_owners.users.add(self.scenario.user)
+        self.playground.add_user(
+            self.scenario.workspace_owners, self.scenario.user
+        )
         response = self.post(work_request_id=self.work_request.id)
 
         self.assertResponseProblem(
@@ -1441,7 +1474,9 @@ class WorkRequestUnblockViewTests(WorkRequestTestCase):
 
     def test_post_work_request_not_found(self) -> None:
         """Return HTTP 404 if the WorkRequest id does not exist."""
-        self.scenario.workspace_owners.users.add(self.scenario.user)
+        self.playground.add_user(
+            self.scenario.workspace_owners, self.scenario.user
+        )
 
         max_id = WorkRequest.objects.aggregate(Max("id"))["id__max"]
         response = self.post(work_request_id=max_id + 1)
@@ -1455,7 +1490,9 @@ class WorkRequestUnblockViewTests(WorkRequestTestCase):
 
     def test_post_not_manual(self) -> None:
         """The work request must have the manual unblock strategy."""
-        self.scenario.workspace_owners.users.add(self.scenario.user)
+        self.playground.add_user(
+            self.scenario.workspace_owners, self.scenario.user
+        )
 
         self.work_request.unblock_strategy = WorkRequest.UnblockStrategy.DEPS
         self.work_request.save()
@@ -1469,7 +1506,9 @@ class WorkRequestUnblockViewTests(WorkRequestTestCase):
 
     def test_post_not_part_of_workflow(self) -> None:
         """The work request must be part of a workflow."""
-        self.scenario.workspace_owners.users.add(self.scenario.user)
+        self.playground.add_user(
+            self.scenario.workspace_owners, self.scenario.user
+        )
         work_request = self.playground.create_work_request(
             task_name="noop",
             status=WorkRequest.Statuses.BLOCKED,
@@ -1485,7 +1524,9 @@ class WorkRequestUnblockViewTests(WorkRequestTestCase):
 
     def test_post_not_blocked(self) -> None:
         """The work request must currently be blocked."""
-        self.scenario.workspace_owners.users.add(self.scenario.user)
+        self.playground.add_user(
+            self.scenario.workspace_owners, self.scenario.user
+        )
         self.work_request.status = WorkRequest.Statuses.PENDING
         self.work_request.save()
 
@@ -1497,7 +1538,9 @@ class WorkRequestUnblockViewTests(WorkRequestTestCase):
 
     def test_post_accept(self) -> None:
         """Accept a blocked work request."""
-        self.scenario.workspace_owners.users.add(self.scenario.user)
+        self.playground.add_user(
+            self.scenario.workspace_owners, self.scenario.user
+        )
 
         response = self.post(
             work_request_id=self.work_request.id,
@@ -1522,7 +1565,9 @@ class WorkRequestUnblockViewTests(WorkRequestTestCase):
 
     def test_post_reject(self) -> None:
         """Reject a blocked work request."""
-        self.scenario.workspace_owners.users.add(self.scenario.user)
+        self.playground.add_user(
+            self.scenario.workspace_owners, self.scenario.user
+        )
 
         response = self.post(
             work_request_id=self.work_request.id,
@@ -1548,7 +1593,9 @@ class WorkRequestUnblockViewTests(WorkRequestTestCase):
 
     def test_post_record_notes_only(self) -> None:
         """Record notes on a blocked work request."""
-        self.scenario.workspace_owners.users.add(self.scenario.user)
+        self.playground.add_user(
+            self.scenario.workspace_owners, self.scenario.user
+        )
 
         response = self.post(
             work_request_id=self.work_request.id, notes="Not sure"
@@ -1570,7 +1617,9 @@ class WorkRequestUnblockViewTests(WorkRequestTestCase):
 
     def test_post_reject_retry_accept(self) -> None:
         """Reject a blocked work request, then retry it, then accept it."""
-        self.scenario.workspace_owners.users.add(self.scenario.user)
+        self.playground.add_user(
+            self.scenario.workspace_owners, self.scenario.user
+        )
 
         response = self.post(
             work_request_id=self.work_request.id,
