@@ -75,6 +75,7 @@ class RegisterViewTests(TestCase):
         self.assertLessEqual(token.created_at, timezone.now())
         self.assertIsNone(token.user)
         self.assertEqual(token.comment, '')
+        self.assertFalse(token.enabled)
 
     def test_create_token_and_worker_duplicate_name(self) -> None:
         """Token is created and Worker disambiguated if needed."""
@@ -148,6 +149,47 @@ class RegisterViewTests(TestCase):
 
         self.assertFalse(Worker.objects.filter(name='worker-lan').exists())
 
+    def test_activation_token(self) -> None:
+        """Register using an activation token."""
+        activation_token = self.playground.create_worker_activation_token()
+        worker = activation_token.activating_worker
+        assert worker is not None
+        token_key = secrets.token_hex(32)
+        data = {"token": token_key, "fqdn": "worker.lan"}
+
+        response = self.client.post(
+            reverse("api:register"),
+            data,
+            headers={"token": activation_token.key},
+        )
+
+        self.assertEqual(response.status_code, status.HTTP_201_CREATED)
+        worker.refresh_from_db()
+        self.assertIsNone(worker.activation_token)
+        token = Token.objects.get_token_or_none(token_key=token_key)
+        assert token is not None
+        self.assertEqual(token.worker, worker)
+        self.assertTrue(token.enabled)
+        self.assertFalse(
+            Token.objects.get_token_or_none(token_key=activation_token.key)
+        )
+
+    def test_invalid_activation_token(self) -> None:
+        """An invalid activation token creates a new worker instead."""
+        token_key = secrets.token_hex(32)
+        data = {"token": token_key, "fqdn": "worker.lan"}
+
+        response = self.client.post(
+            reverse("api:register"), data, headers={"token": token_key}
+        )
+
+        self.assertEqual(response.status_code, status.HTTP_201_CREATED)
+        token = Token.objects.get_token_or_none(token_key=token_key)
+        assert token is not None
+        worker = token.worker
+        self.assertEqual(worker.name, "worker-lan")
+        self.assertFalse(token.enabled)
+
 
 class GetNextWorkRequestViewTests(WorkRequestTestCase):
     """Tests for GetNextWorkRequestView."""
