@@ -11,6 +11,7 @@
 
 from typing import Any
 
+from django.conf import settings
 from django.http.response import HttpResponseBase
 from django.urls import reverse
 from rest_framework import status
@@ -20,7 +21,6 @@ from rest_framework.test import APIClient
 from debusine.artifacts.models import ArtifactCategory
 from debusine.db.context import context
 from debusine.db.models import (
-    DEFAULT_WORKSPACE_NAME,
     WorkRequest,
     WorkflowTemplate,
     Workspace,
@@ -243,7 +243,7 @@ class WorkflowTemplateViewTests(TestCase):
         response = self.post_workflow_template(
             {
                 "name": "test",
-                "workspace": DEFAULT_WORKSPACE_NAME,
+                "workspace": settings.DEBUSINE_DEFAULT_WORKSPACE,
                 "task_name": "noop",
             }
         )
@@ -268,7 +268,7 @@ class WorkflowTemplateViewTests(TestCase):
         response = self.post_workflow_template(
             {
                 "name": "test",
-                "workspace": DEFAULT_WORKSPACE_NAME,
+                "workspace": settings.DEBUSINE_DEFAULT_WORKSPACE,
                 "task_name": "sbuild",
                 "task_data": task_data,
                 "priority": 0,
@@ -438,7 +438,7 @@ class WorkflowTemplateViewTests(TestCase):
         response = self.post_workflow_template(
             {
                 "name": "test",
-                "workspace": DEFAULT_WORKSPACE_NAME,
+                "workspace": settings.DEBUSINE_DEFAULT_WORKSPACE,
                 "task_name": "noop",
                 "priority": 1,
             }
@@ -463,7 +463,7 @@ class WorkflowTemplateViewTests(TestCase):
         response = self.post_workflow_template(
             {
                 "name": "test",
-                "workspace": DEFAULT_WORKSPACE_NAME,
+                "workspace": settings.DEBUSINE_DEFAULT_WORKSPACE,
                 "task_name": "noop",
                 "priority": 1,
             }
@@ -809,7 +809,7 @@ class WorkflowViewTests(TestCase):
         self.assertDictContainsAll(
             response.json(),
             {
-                "workspace": DEFAULT_WORKSPACE_NAME,
+                "workspace": settings.DEBUSINE_DEFAULT_WORKSPACE,
                 "created_by": self.token.user_id,
                 "task_type": TaskTypes.WORKFLOW,
                 "task_name": "sbuild",
