@@ -59,8 +59,8 @@ from debusine.server.views.base import (
 )
 from debusine.server.views.rest import (
     IsGet,
-    IsTokenAuthenticated,
     IsTokenUserAuthenticated,
+    IsWorkerAuthenticated,
 )
 from debusine.tasks import BaseTask
 from debusine.tasks.models import ActionTypes, TaskTypes
@@ -80,7 +80,7 @@ class WorkRequestView(
     """View used by the debusine client to get information of a WorkRequest."""
 
     permission_classes = [
-        IsTokenUserAuthenticated | IsTokenAuthenticated & IsGet
+        IsTokenUserAuthenticated | IsWorkerAuthenticated & IsGet
     ]
     serializer_class = WorkRequestSerializer
     filter_backends = [CanDisplayFilterBackend]
