@@ -11,11 +11,9 @@
 
 from functools import cached_property
 
-from debusine.artifacts import SourcePackage
-from debusine.artifacts.models import ArtifactCategory, DebianSourcePackage
-from debusine.client.models import LookupChildType
-from debusine.db.models import Artifact, WorkRequest
-from debusine.server.collections.lookup import lookup_single
+from debusine.artifacts.models import ArtifactCategory
+from debusine.db.models import WorkRequest
+from debusine.server.workflows import workflow_utils
 from debusine.server.workflows.base import Workflow, WorkflowValidationError
 from debusine.server.workflows.models import (
     AutopkgtestWorkflowData,
@@ -50,7 +48,9 @@ class AutopkgtestWorkflow(
         assert self.workspace is not None
 
         try:
-            architectures = self.get_architectures(self.data.binary_artifacts)
+            architectures = workflow_utils.get_architectures(
+                self, self.data.binary_artifacts
+            )
         except ValueError as e:
             raise WorkflowValidationError(str(e)) from e
 
@@ -77,11 +77,15 @@ class AutopkgtestWorkflow(
         """Create an autopkgtest work request for a single architecture."""
         assert self.work_request is not None
 
-        filtered_binary_artifacts = self.filter_artifact_lookup_by_arch(
-            self.data.binary_artifacts, (architecture, "all")
+        filtered_binary_artifacts = (
+            workflow_utils.filter_artifact_lookup_by_arch(
+                self, self.data.binary_artifacts, (architecture, "all")
+            )
         )
-        filtered_context_artifacts = self.filter_artifact_lookup_by_arch(
-            self.data.context_artifacts, (architecture, "all")
+        filtered_context_artifacts = (
+            workflow_utils.filter_artifact_lookup_by_arch(
+                self, self.data.context_artifacts, (architecture, "all")
+            )
         )
         task_data = AutopkgtestData(
             input=AutopkgtestInput(
@@ -141,29 +145,15 @@ class AutopkgtestWorkflow(
             for architecture in new_architectures:
                 self._populate_single(architecture)
 
-    # TODO refactor with QaWorkflow, DebianPipelineWorkflow and SbuildWorkflow
-    @cached_property
-    def source_package(self) -> Artifact:
-        """Source package artifact."""
-        artifact = lookup_single(
-            self.data.source_artifact,
-            self.workspace,
-            user=self.work_request.created_by,
-            expect_type=LookupChildType.ARTIFACT,
-        ).artifact
-        return self.locate_debian_source_package("source_artifact", artifact)
-
-    # TODO refactor with QaWorkflow, DebianPipelineWorkflow and SbuildWorkflow
-    @cached_property
-    def source_package_data(self) -> DebianSourcePackage:
-        """Parsed source package artifact data."""
-        return SourcePackage.create_data(self.source_package.data)
-
-    def compute_dynamic_data(
+    def build_dynamic_data(
         self, task_database: TaskDatabaseInterface  # noqa: U100
     ) -> BaseDynamicTaskData:
-        """Compute dynamic data for this workflow."""
-        source_data = self.source_package_data
+        """
+        Compute dynamic data for this workflow.
+
+        :subject: package name of ``source_artifact``
+        """
+        source_data = workflow_utils.source_package_data(self)
         return BaseDynamicTaskData(
             subject=source_data.name,
             parameter_summary=f"{source_data.name}_{source_data.version}",
