@@ -14,8 +14,6 @@ here.
 """
 import logging
 from abc import ABCMeta, abstractmethod
-from collections.abc import Collection as AbcCollection
-from collections.abc import Iterable, Sequence
 from typing import Any, TypeVar, TypedDict, cast
 
 from django.contrib.auth.models import AnonymousUser
@@ -24,20 +22,12 @@ from debusine.artifacts.models import (
     ArtifactCategory,
     BareDataCategory,
     CollectionCategory,
-    DebianBinaryPackage,
-    DebianBinaryPackages,
-    DebianPackageBuildLog,
-    DebianSourcePackage,
-    DebianUpload,
-    get_source_package_name,
 )
 from debusine.client.models import (
     LookupChildType,
     model_to_json_serializable_dict,
 )
 from debusine.db.models import (
-    Artifact,
-    ArtifactRelation,
     Collection,
     CollectionItem,
     TaskDatabase,
@@ -46,12 +36,7 @@ from debusine.db.models import (
     Workspace,
 )
 from debusine.db.models.work_requests import InternalTaskError
-from debusine.server.collections.lookup import (
-    LookupResult,
-    lookup_multiple,
-    lookup_single,
-    reconstruct_lookup,
-)
+from debusine.server.collections.lookup import lookup_multiple, lookup_single
 from debusine.server.tasks.base import BaseServerTask
 from debusine.server.workflows.models import (
     BaseWorkflowData,
@@ -97,7 +82,7 @@ class Workflow(BaseServerTask[WD, DTD], metaclass=ABCMeta):
     """
     Base class for workflow orchestrators.
 
-    This is the base API for running :class:`WorkflowInstance` logic
+    This is the base API for running :class:`WorkflowInstance` logic.
     """
 
     TASK_TYPE = TaskTypes.WORKFLOW
@@ -166,16 +151,15 @@ class Workflow(BaseServerTask[WD, DTD], metaclass=ABCMeta):
                 )
                 return False
 
-            if dynamic_task_data is not None:
-                self.work_request.dynamic_task_data = (
-                    model_to_json_serializable_dict(
-                        dynamic_task_data, exclude_unset=True
-                    )
-                )
-                self.work_request.save()
-                self.dynamic_data = self.dynamic_task_data_type(
-                    **self.work_request.dynamic_task_data
+            self.work_request.dynamic_task_data = (
+                model_to_json_serializable_dict(
+                    dynamic_task_data, exclude_unset=True
                 )
+            )
+            self.work_request.save()
+            self.dynamic_data = self.dynamic_task_data_type(
+                **self.work_request.dynamic_task_data
+            )
 
         return True
 
@@ -185,11 +169,11 @@ class Workflow(BaseServerTask[WD, DTD], metaclass=ABCMeta):
         Create the initial WorkRequest structure.
 
         This is called once, when the workflow first becomes runnable.
-        validate_input will already have been called.
+        :py:meth:`validate_input` will already have been called.
 
         This method is required to be idempotent: calling it multiple times
-        with the same argument MUST result in the same WorkRequest structure as
-        calling it once
+        with the same argument MUST result in the same
+        :py:class:`WorkRequest` structure as calling it once.
         """
 
     def callback(self, work_request: "WorkRequest") -> None:
@@ -197,15 +181,15 @@ class Workflow(BaseServerTask[WD, DTD], metaclass=ABCMeta):
         Perform an orchestration step.
 
         Called with the workflow callback work request (note that this is
-        not the same as `self.work_request`) when the workflow node becomes
-        ready to execute.
+        not the same as ``self.work_request``) when the workflow node
+        becomes ready to execute.
 
-        Called with a WorkRequest of type internal/workflow to perform an
-        orchestration step triggered by a workflow callback.
+        Called with a :py:class:`WorkRequest` of type internal/workflow to
+        perform an orchestration step triggered by a workflow callback.
 
         This method is required to be idempotent: calling it multiple times
-        with the same argument MUST result in the same WorkRequest structure as
-        calling it once
+        with the same argument MUST result in the same
+        :py:class:`WorkRequest` structure as calling it once.
         """
         # Do nothing by default
 
@@ -218,21 +202,22 @@ class Workflow(BaseServerTask[WD, DTD], metaclass=ABCMeta):
         data: dict[str, Any] | None = None,
         artifact_filters: dict[str, Any] | None = None,  # noqa: U100
     ) -> None:
-        r"""
+        """
         Indicate work_request will provide an artifact.
 
         :param work_request: work request that will provide the artifact
         :param category: category of the artifact that will be provided
         :param name: name of this item in the workflow’s internal collection
         :param data: add it to the data dictionary for the event reaction
-        :param artifact_filters: for the ActionUpdateCollectionWithArtifacts to
-          allow workflows to add filtering
-        :raise LookupError: if a key in "data" starts with promise\_
+        :param artifact_filters: for the
+          :ref:`action-update-collection-with-artifacts` action, to allow
+          workflows to add filtering
+        :raise LookupError: if a key in "data" starts with ``promise_``
 
-        Create an event reaction for on_creation adding a promise: this
+        Create an event reaction for ``on_creation`` adding a promise: this
         work request will create an artifact.
 
-        Create an event reaction for on_success to update the collection
+        Create an event reaction for ``on_success`` to update the collection
         with the relevant artifact.
         """
         if data is not None:
@@ -290,7 +275,7 @@ class Workflow(BaseServerTask[WD, DTD], metaclass=ABCMeta):
         Indicate that work_request requires input (lookup).
 
         :param work_request: for each lookup result call
-          work_request.add_dependency(promise["promise_work_request_id"])
+          ``work_request.add_dependency(promise["promise_work_request_id"])``
         :param lookup: resolve the lookup and iterate over the results
           (for PROMISES only)
         """
@@ -338,7 +323,7 @@ class Workflow(BaseServerTask[WD, DTD], metaclass=ABCMeta):
         """
         Create the child if one does not already exist.
 
-        :return: new WorkRequest or existing work request.
+        :return: new or existing :py:class:`WorkRequest`.
         """
         try:
             return self.work_request.children.get(
@@ -372,99 +357,6 @@ class Workflow(BaseServerTask[WD, DTD], metaclass=ABCMeta):
                 ),
             )
 
-    def get_available_architectures(
-        self, *, vendor: str, codename: str
-    ) -> set[str]:
-        """Get architectures available for use with this vendor/codename."""
-        architectures = set()
-
-        for result in lookup_multiple(
-            LookupMultiple.parse_obj(
-                {"collection": vendor, "data__codename": codename}
-            ),
-            self.workspace,
-            user=self.work_request.created_by,
-            default_category=CollectionCategory.ENVIRONMENTS,
-            expect_type=LookupChildType.ARTIFACT,
-        ):
-            architectures.add(result.artifact.data.get("architecture"))
-
-        architectures.add("all")
-
-        return architectures
-
-    @staticmethod
-    def lookup_result_architecture(result: LookupResult) -> str:
-        """Get architecture from result of looking up an artifact."""
-        architecture: str | None
-
-        if result.artifact is not None:
-            artifact_data = result.artifact.create_data()
-            match artifact_data:
-                case DebianBinaryPackages():
-                    architecture = artifact_data.architecture
-                case DebianBinaryPackage():
-                    architecture = artifact_data.deb_fields.get("Architecture")
-                case DebianUpload():
-                    architecture = artifact_data.changes_fields.get(
-                        "Architecture"
-                    )
-                case _:
-                    raise ArtifactHasNoArchitecture(f"{type(artifact_data)}")
-
-            assert isinstance(architecture, str)
-            return architecture
-
-        elif result.collection_item is not None:
-            architecture = result.collection_item.data.get("architecture")
-            if isinstance(architecture, str):
-                return architecture
-
-        else:
-            raise ValueError(
-                "Unexpected result: must have collection_item or artifact"
-            )
-
-        raise ValueError(
-            f"Cannot determine architecture for lookup result: {result}"
-        )
-
-    def filter_artifact_lookup_by_arch(
-        self, lookup: LookupMultiple, architectures: Iterable[str]
-    ) -> LookupMultiple:
-        """Filter an artifact lookup by architecture."""
-        results = lookup_multiple(
-            lookup,
-            self.workspace,
-            user=self.work_request.created_by,
-            workflow_root=self.work_request.get_workflow_root(),
-            expect_type=LookupChildType.ARTIFACT_OR_PROMISE,
-        )
-        relevant: list[LookupSingle] = []
-        for result in results:
-            arch_in_lookup = self.lookup_result_architecture(result)
-            if arch_in_lookup in architectures:
-                relevant.append(reconstruct_lookup(result))
-
-        return LookupMultiple.parse_obj(sorted(relevant))
-
-    def get_architectures(self, lookup: LookupMultiple) -> set[str]:
-        """
-        Return set with all the architectures in the artifacts from the lookup.
-
-        The architectures are extracted from each lookup result using
-        :py:meth:`lookup_result_architecture`.
-        """
-        results = lookup_multiple(
-            lookup,
-            self.workspace,
-            user=self.work_request.created_by,
-            workflow_root=self.work_request.get_workflow_root(),
-            expect_type=LookupChildType.ARTIFACT_OR_PROMISE,
-        )
-
-        return {self.lookup_result_architecture(result) for result in results}
-
     def lookup_singleton_collection(
         self,
         category: CollectionCategory,
@@ -484,174 +376,13 @@ class Workflow(BaseServerTask[WD, DTD], metaclass=ABCMeta):
         """Unused abstract method from BaseTask: populate() is used instead."""
         raise NotImplementedError()
 
-    @staticmethod
-    def follow_artifact_relation(
-        artifact: Artifact,
-        relation_type: ArtifactRelation.Relations,
-        category: ArtifactCategory,
-    ) -> Artifact:
-        """Follow relations from artifact to find an artifact of category."""
-        try:
-            relation = artifact.relations.get(
-                type=relation_type, target__category=category
-            )
-        except ArtifactRelation.DoesNotExist:
-            raise TaskConfigError(
-                f"Unable to find an artifact of category {category.value} with "
-                f'a relationship of type {relation_type} from "{artifact}"'
-            )
-        except ArtifactRelation.MultipleObjectsReturned:
-            raise TaskConfigError(
-                f"Multiple artifacts of category {category.value} with "
-                f'a relationship of type {relation_type} from "{artifact}" '
-                f"found"
-            )
-        return relation.target
-
-    @classmethod
-    def locate_debian_source_package(
-        cls, configuration_key: str, artifact: Artifact
-    ) -> Artifact:
-        """
-        Accept a debian:upload or debian:source-package in a workflow.
-
-        Resolve to the debian:source-package.
-        """
-        cls.ensure_artifact_categories(
-            configuration_key=configuration_key,
-            category=artifact.category,
-            expected=[ArtifactCategory.SOURCE_PACKAGE, ArtifactCategory.UPLOAD],
-        )
-        match artifact.category:
-            case ArtifactCategory.SOURCE_PACKAGE:
-                return artifact
-            case ArtifactCategory.UPLOAD:
-                return cls.follow_artifact_relation(
-                    artifact,
-                    ArtifactRelation.Relations.EXTENDS,
-                    ArtifactCategory.SOURCE_PACKAGE,
-                )
-            case _ as unreachable:  # pragma: no cover
-                raise AssertionError(
-                    f"Unexpected artifact category: {unreachable}"
-                )
-
-    def locate_debian_source_package_lookup(
-        self, configuration_key: str, lookup: LookupSingle
-    ) -> LookupSingle:
-        """
-        Return a lookup to a debian:source-package.
-
-        If the specified lookup returns a debian:source-package, return it.
-        If it returns a debian:upload, find the related debian:source-package
-        and return a lookup to it.
-        """
-        artifact = lookup_single(
-            lookup,
-            self.workspace,
-            user=self.work_request.created_by,
-            workflow_root=self.work_request.get_workflow_root(),
-            expect_type=LookupChildType.ARTIFACT,
-        ).artifact
-        if artifact.category == ArtifactCategory.UPLOAD:
-            source_package = self.locate_debian_source_package(
-                configuration_key, artifact
-            )
-            return f"{source_package.id}@artifacts"
-        self.ensure_artifact_categories(
-            configuration_key=configuration_key,
-            category=artifact.category,
-            expected=[ArtifactCategory.SOURCE_PACKAGE],
-        )
-        return lookup
-
-    @classmethod
-    def get_source_package_names(
-        cls,
-        results: Sequence[LookupResult],
-        *,
-        configuration_key: str,
-        artifact_expected_categories: AbcCollection[ArtifactCategory],
-    ) -> list[str]:
-        """
-        Return a sorted list of source package names from results.
-
-        It ensures that:
-
-        - The `LookupResult` objects contain either an artifact or promise.
-        - Artifacts belong to the artifact_expected_categories.
-        - If `LookupResult` is a promise: extracts the name from the promise
-          data "source_package_name".
-
-        :param results: A sequence of `LookupResult` objects representing
-          artifacts to be processed. Each entry is expected to be either an
-          artifact or a promise.
-        :param configuration_key: A string used by
-          `cls.ensure_artifact_categories` for the exception message.
-        :param artifact_expected_categories: valid `ArtifactCategory` that
-          artifacts must belong to.
-        :return: A sorted list of source package names.
-        """
-        source_package_names = set()
-
-        for result in results:
-            # lookup_multiple expect_type: only artifacts or promises
-            match result.result_type:
-                case CollectionItem.Types.ARTIFACT:
-                    assert result.artifact is not None
-                    category = result.artifact.category
-
-                    cls.ensure_artifact_categories(
-                        configuration_key=configuration_key,
-                        category=category,
-                        expected=artifact_expected_categories,
-                    )
-                    artifact_data = result.artifact.create_data()
-
-                    assert isinstance(
-                        artifact_data,
-                        (
-                            DebianSourcePackage,
-                            DebianUpload,
-                            DebianBinaryPackage,
-                            DebianBinaryPackages,
-                            DebianPackageBuildLog,
-                        ),
-                    )
-                    source_package_names.add(
-                        get_source_package_name(artifact_data)
-                    )
-
-                case _:
-                    # Makes coverage happy
-                    # It's a promise.
-                    assert result.result_type == CollectionItem.Types.BARE
-                    assert result.collection_item is not None
-
-                    cls.ensure_artifact_categories(
-                        configuration_key=configuration_key,
-                        category=result.collection_item.data[
-                            "promise_category"
-                        ],
-                        expected=artifact_expected_categories,
-                    )
-
-                    if (
-                        package_name := result.collection_item.data.get(
-                            "source_package_name"
-                        )
-                    ) is not None:
-                        source_package_names.add(package_name)
-
-        return sorted(source_package_names)
-
 
 def orchestrate_workflow(work_request: WorkRequest) -> None:
     """
     Orchestrate a workflow in whatever way is appropriate.
 
-    For a workflow callback, run `callback` and mark the work request as
-    completed.  For a workflow, run `populate` and unblock workflow
+    For a workflow callback, run ``callback`` and mark the work request as
+    completed.  For a workflow, run ``populate`` and unblock workflow
     children, but leave the workflow running until all its children have
     finished.  For any other work request, raise an error.
     """
