@@ -8,14 +8,8 @@
 # contained in the LICENSE file.
 
 """lintian workflow."""
-from functools import cached_property
-
-from debusine.artifacts import SourcePackage
-from debusine.artifacts.models import DebianSourcePackage
-from debusine.client.models import LookupChildType
-from debusine.db.models import Artifact, WorkRequest
-from debusine.server.collections.lookup import lookup_single
-from debusine.server.workflows import Workflow
+from debusine.db.models import WorkRequest
+from debusine.server.workflows import Workflow, workflow_utils
 from debusine.server.workflows.models import (
     LintianWorkflowData,
     WorkRequestWorkflowData,
@@ -40,7 +34,9 @@ class LintianWorkflow(Workflow[LintianWorkflowData, BaseDynamicTaskData]):
 
     def populate(self) -> None:
         """Create work requests."""
-        architectures = self.get_architectures(self.data.binary_artifacts)
+        architectures = workflow_utils.get_architectures(
+            self, self.data.binary_artifacts
+        )
 
         if (data_archs := self.data.architectures) is not None:
             architectures.intersection_update(data_archs)
@@ -51,8 +47,10 @@ class LintianWorkflow(Workflow[LintianWorkflowData, BaseDynamicTaskData]):
         environment = f"{self.data.vendor}/match:codename={self.data.codename}"
 
         for arch in architectures:
-            filtered_binary_artifacts = self.filter_artifact_lookup_by_arch(
-                self.data.binary_artifacts, (arch, "all")
+            filtered_binary_artifacts = (
+                workflow_utils.filter_artifact_lookup_by_arch(
+                    self, self.data.binary_artifacts, (arch, "all")
+                )
             )
 
             self._populate_lintian(
@@ -108,29 +106,15 @@ class LintianWorkflow(Workflow[LintianWorkflowData, BaseDynamicTaskData]):
 
         return wr
 
-    # TODO refactor with QaWorkflow, DebianPipelineWorkflow and SbuildWorkflow
-    @cached_property
-    def source_package(self) -> Artifact:
-        """Source package artifact."""
-        artifact = lookup_single(
-            self.data.source_artifact,
-            self.workspace,
-            user=self.work_request.created_by,
-            expect_type=LookupChildType.ARTIFACT,
-        ).artifact
-        return self.locate_debian_source_package("source_artifact", artifact)
-
-    # TODO refactor with QaWorkflow, DebianPipelineWorkflow and SbuildWorkflow
-    @cached_property
-    def source_package_data(self) -> DebianSourcePackage:
-        """Parsed source package artifact data."""
-        return SourcePackage.create_data(self.source_package.data)
-
-    def compute_dynamic_data(
+    def build_dynamic_data(
         self, task_database: TaskDatabaseInterface  # noqa: U100
     ) -> BaseDynamicTaskData:
-        """Compute dynamic data for this workflow."""
-        source_data = self.source_package_data
+        """
+        Compute dynamic data for this workflow.
+
+        :subject: package name of ``source_artifact``
+        """
+        source_data = workflow_utils.source_package_data(self)
         return BaseDynamicTaskData(
             subject=source_data.name,
             parameter_summary=f"{source_data.name}_{source_data.version}",
