@@ -21,7 +21,6 @@ from debusine.db.context import context
 from debusine.db.models import Artifact, TaskDatabase, WorkRequest
 from debusine.server.workflows import (
     AutopkgtestWorkflow,
-    Workflow,
     WorkflowValidationError,
 )
 from debusine.server.workflows.base import orchestrate_workflow
@@ -30,6 +29,7 @@ from debusine.server.workflows.models import (
     BaseWorkflowData,
     SbuildWorkflowData,
 )
+from debusine.server.workflows.tests.helpers import TestWorkflow
 from debusine.tasks.models import (
     AutopkgtestNeedsInternet,
     BackendType,
@@ -40,9 +40,8 @@ from debusine.tasks.models import (
     SbuildInput,
     TaskTypes,
 )
-from debusine.tasks.tests.helper_mixin import TestTaskMixin
 from debusine.test.django import TestCase
-from debusine.test.utils import preserve_task_registry
+from debusine.test.test_utils import preserve_task_registry
 
 
 class AutopkgtestWorkflowTests(TestCase):
@@ -244,7 +243,7 @@ class AutopkgtestWorkflowTests(TestCase):
         with preserve_task_registry():
 
             class ExamplePipeline(
-                TestTaskMixin, Workflow[BaseWorkflowData, BaseDynamicTaskData]
+                TestWorkflow[BaseWorkflowData, BaseDynamicTaskData]
             ):
                 """Pipeline workflow that runs sbuild and autopkgtest."""
 
