@@ -26,22 +26,22 @@ from debusine.db.models import Artifact, TaskDatabase, WorkRequest
 from debusine.server.collections.lookup import lookup_multiple, lookup_single
 from debusine.server.scheduler import schedule
 from debusine.server.workflows import MakeSignedSourceWorkflow
-from debusine.server.workflows.base import Workflow, orchestrate_workflow
+from debusine.server.workflows.base import orchestrate_workflow
 from debusine.server.workflows.models import (
     BaseWorkflowData,
     MakeSignedSourceWorkflowData,
     SbuildWorkflowData,
     WorkRequestWorkflowData,
 )
+from debusine.server.workflows.tests.helpers import TestWorkflow
 from debusine.tasks.models import (
     BaseDynamicTaskData,
     LookupMultiple,
     SbuildInput,
     TaskTypes,
 )
-from debusine.tasks.tests.helper_mixin import TestTaskMixin
 from debusine.test.django import TestCase
-from debusine.test.utils import preserve_task_registry
+from debusine.test.test_utils import preserve_task_registry
 
 
 class MakeSignedSourceWorkflowTests(TestCase):
@@ -113,7 +113,7 @@ class MakeSignedSourceWorkflowTests(TestCase):
         source_artifact = self.playground.create_source_artifact()
 
         class ExamplePipeline(
-            TestTaskMixin, Workflow[BaseWorkflowData, BaseDynamicTaskData]
+            TestWorkflow[BaseWorkflowData, BaseDynamicTaskData]
         ):
             """Pipeline workflow."""
 
