@@ -20,13 +20,14 @@ from debusine.artifacts.models import (
 from debusine.db.context import context
 from debusine.db.models import Artifact, TaskDatabase, WorkRequest
 from debusine.server.collections.debian_suite import DebianSuiteManager
-from debusine.server.workflows import QAWorkflow
-from debusine.server.workflows.base import Workflow, orchestrate_workflow
+from debusine.server.workflows import QAWorkflow, workflow_utils
+from debusine.server.workflows.base import orchestrate_workflow
 from debusine.server.workflows.models import (
     BaseWorkflowData,
     QAWorkflowData,
     SbuildWorkflowData,
 )
+from debusine.server.workflows.tests.helpers import TestWorkflow
 from debusine.tasks import TaskConfigError
 from debusine.tasks.models import (
     BackendType,
@@ -36,9 +37,8 @@ from debusine.tasks.models import (
     SbuildInput,
     TaskTypes,
 )
-from debusine.tasks.tests.helper_mixin import TestTaskMixin
 from debusine.test.django import TestCase
-from debusine.test.utils import preserve_task_registry
+from debusine.test.test_utils import preserve_task_registry
 
 
 class QAWorkflowTests(TestCase):
@@ -70,7 +70,7 @@ class QAWorkflowTests(TestCase):
         """Create a QAWorkflow and call orchestrate_workflow."""
 
         class ExamplePipeline(
-            TestTaskMixin, Workflow[BaseWorkflowData, BaseDynamicTaskData]
+            TestWorkflow[BaseWorkflowData, BaseDynamicTaskData]
         ):
             """Example workflow."""
 
@@ -213,7 +213,9 @@ class QAWorkflowTests(TestCase):
             ),
         )
         workflow = QAWorkflow(wr)
-        self.assertEqual(workflow.source_package, upload_artifacts.source)
+        self.assertEqual(
+            workflow_utils.source_package(workflow), upload_artifacts.source
+        )
 
     @preserve_task_registry()
     def test_populate(self) -> None:
