@@ -25,10 +25,7 @@ from debusine.db.context import context
 from debusine.db.models import Artifact, Collection, TaskDatabase, WorkRequest
 from debusine.server.collections.debian_suite import DebianSuiteManager
 from debusine.server.collections.lookup import lookup_single
-from debusine.server.workflows import (
-    ReverseDependenciesAutopkgtestWorkflow,
-    Workflow,
-)
+from debusine.server.workflows import ReverseDependenciesAutopkgtestWorkflow
 from debusine.server.workflows.base import orchestrate_workflow
 from debusine.server.workflows.models import (
     BaseWorkflowData,
@@ -40,6 +37,7 @@ from debusine.server.workflows.reverse_dependencies_autopkgtest import (
     _BinaryPackage,
     _SourcePackage,
 )
+from debusine.server.workflows.tests.helpers import TestWorkflow
 from debusine.tasks import TaskConfigError
 from debusine.tasks.models import (
     AutopkgtestNeedsInternet,
@@ -52,9 +50,8 @@ from debusine.tasks.models import (
     SbuildInput,
     TaskTypes,
 )
-from debusine.tasks.tests.helper_mixin import TestTaskMixin
 from debusine.test.django import TestCase
-from debusine.test.utils import preserve_task_registry
+from debusine.test.test_utils import preserve_task_registry
 
 
 class ReverseDependenciesAutopkgtestWorkflowTests(TestCase):
@@ -588,7 +585,7 @@ class ReverseDependenciesAutopkgtestWorkflowTests(TestCase):
         with preserve_task_registry():
 
             class ExamplePipeline(
-                TestTaskMixin, Workflow[BaseWorkflowData, BaseDynamicTaskData]
+                TestWorkflow[BaseWorkflowData, BaseDynamicTaskData]
             ):
                 """Pipeline workflow that runs sbuild and rdep-autopkgtest."""
 
