@@ -25,7 +25,11 @@ from debusine.db.models import (
     default_workspace,
 )
 from debusine.server.collections.tests.utils import CollectionTestMixin
-from debusine.server.workflows import SbuildWorkflow, WorkflowValidationError
+from debusine.server.workflows import (
+    SbuildWorkflow,
+    WorkflowValidationError,
+    workflow_utils,
+)
 from debusine.server.workflows.base import orchestrate_workflow
 from debusine.server.workflows.models import SbuildWorkflowData
 from debusine.tasks import TaskConfigError
@@ -37,7 +41,7 @@ from debusine.tasks.models import (
     TaskTypes,
 )
 from debusine.test.django import TestCase
-from debusine.test.utils import create_system_tarball_data
+from debusine.test.test_utils import create_system_tarball_data
 
 
 class SbuildWorkflowTests(CollectionTestMixin, TestCase):
@@ -145,7 +149,7 @@ class SbuildWorkflowTests(CollectionTestMixin, TestCase):
         self.assertEqual(wr.status, WorkRequest.Statuses.PENDING)
 
         o = SbuildWorkflow(wr)
-        self.assertEqual(o.source_package, source)
+        self.assertEqual(workflow_utils.source_package(o), source)
         self.assertEqual(o.architectures, {"all"})
         self.assertEqual(o._get_environment("amd64"), tarball_item.artifact)
         o.validate_input()
@@ -778,7 +782,7 @@ class SbuildWorkflowTests(CollectionTestMixin, TestCase):
             r"'debusine:test'. Valid categories: "
             r"\['debian:source-package', 'debian:upload'\]$",
         ):
-            orchestrator.source_package
+            workflow_utils.source_package_data(orchestrator)
 
         source = self.create_source_package(
             "hello", "1.0", dsc_fields={"Architecture": ""}
