@@ -64,6 +64,7 @@ from debusine.tasks.executors import (
     executor_class,
 )
 from debusine.tasks.models import (
+    ActionRecordInTaskHistory,
     BackendType,
     BaseDynamicTaskData,
     BaseDynamicTaskDataWithExecutor,
@@ -459,15 +460,24 @@ class BaseTask(Generic[TD, DTD], metaclass=ABCMeta):
 
         return True
 
+    @abstractmethod
+    def build_dynamic_data(self, task_database: TaskDatabaseInterface) -> DTD:
+        """
+        Build a dynamic task data structure for this task.
+
+        :param task_database: TaskDatabaseInterface to use for lookups
+        :returns: the newly created dynamic task data
+        """
+
     def compute_dynamic_data(
         self, task_database: TaskDatabaseInterface  # noqa: U100
-    ) -> DTD | None:
+    ) -> DTD:
         """
         Compute dynamic data for this task.
 
         This may involve resolving artifact lookups.
         """
-        return None
+        return self.build_dynamic_data(task_database)
 
     def _configure(
         self,
@@ -650,7 +660,10 @@ class BaseTask(Generic[TD, DTD], metaclass=ABCMeta):
         This allows tasks to provide actions that are processed by the
         server at various points in the lifecycle of the work request.
         """
-        return []
+        event_reactions: list[EventReaction] = []
+        if event_name in {"on_success", "on_failure"}:
+            event_reactions.append(ActionRecordInTaskHistory())
+        return event_reactions
 
 
 class BaseExternalTask(BaseTask[TD, DTD], Generic[TD, DTD], metaclass=ABCMeta):
@@ -1537,3 +1550,13 @@ class ExtraRepositoryMixin(
             yield extra_repository.as_oneline_source(
                 signed_by_filename=f"/etc/apt/keyrings/extra_apt_key_{i}.asc"
             )
+
+
+class DefaultDynamicData(BaseTask[TD, BaseDynamicTaskData], metaclass=ABCMeta):
+    """Base class for tasks that do not add to dynamic task data."""
+
+    def build_dynamic_data(
+        self, task_database: TaskDatabaseInterface  # noqa: U100
+    ) -> BaseDynamicTaskData:
+        """Return default dynamic data."""
+        return BaseDynamicTaskData()
