@@ -82,10 +82,14 @@ class ExtractForSigning(
         executor_available_key = f"executor:{self.backend}:available"
         return bool(worker_metadata.get(executor_available_key, False))
 
-    def compute_dynamic_data(
+    def build_dynamic_data(
         self, task_database: TaskDatabaseInterface
     ) -> ExtractForSigningDynamicData:
-        """Resolve artifact lookups for this task."""
+        """
+        Resolve artifact lookups for this task.
+
+        :subject: binary package name of ``template_artifact``
+        """
         template_artifact = task_database.lookup_single_artifact(
             self.data.input.template_artifact
         )
