@@ -54,10 +54,14 @@ class MergeUploads(
         super().__init__(task_data, dynamic_task_data)
         self._changes_files: list[Path] = []
 
-    def compute_dynamic_data(
+    def build_dynamic_data(
         self, task_database: TaskDatabaseInterface
     ) -> MergeUploadsDynamicData:
-        """Resolve artifact lookups for this task."""
+        """
+        Resolve artifact lookups for this task.
+
+        :subject: shared source package name across all uploads
+        """
         upload_artifacts = task_database.lookup_multiple_artifacts(
             self.data.input.uploads
         )
