@@ -445,6 +445,7 @@ class ActionTypes(StrEnum):
     UPDATE_COLLECTION_WITH_ARTIFACTS = "update-collection-with-artifacts"
     UPDATE_COLLECTION_WITH_DATA = "update-collection-with-data"
     RETRY_WITH_DELAYS = "retry-with-delays"
+    RECORD_IN_TASK_HISTORY = "record-in-task-history"
 
 
 class ActionSendNotification(BaseTaskDataModel):
@@ -504,12 +505,23 @@ class ActionRetryWithDelays(BaseTaskDataModel):
         return values
 
 
+class ActionRecordInTaskHistory(BaseTaskDataModel):
+    """Action for recording the task run in a task-history collection."""
+
+    action: Literal[ActionTypes.RECORD_IN_TASK_HISTORY] = (
+        ActionTypes.RECORD_IN_TASK_HISTORY
+    )
+    subject: str | None = None
+    context: str | None = None
+
+
 EventReaction = Annotated[
     Union[
         ActionSendNotification,
         ActionUpdateCollectionWithArtifacts,
         ActionUpdateCollectionWithData,
         ActionRetryWithDelays,
+        ActionRecordInTaskHistory,
     ],
     pydantic.Field(discriminator="action"),
 ]
@@ -891,7 +903,7 @@ class SystemBootstrapRepositoryKeyring(BaseTaskDataModel):
         cls, url: pydantic.AnyUrl | pydantic.FileUrl
     ) -> pydantic.AnyUrl | pydantic.FileUrl:
         """
-        Reject file:// URLs outside /usr/share/keyrings/.
+        Reject file:// URLs outside /usr/(local/)share/keyrings/.
 
         We don't want to allow reading arbitrary paths.
         """
@@ -901,9 +913,15 @@ class SystemBootstrapRepositoryKeyring(BaseTaskDataModel):
             and not (
                 Path(url.path).resolve().is_relative_to("/usr/share/keyrings")
             )
+            and not (
+                Path(url.path)
+                .resolve()
+                .is_relative_to("/usr/local/share/keyrings")
+            )
         ):
             raise ValueError(
-                "file:// URLs for keyrings must be under /usr/share/keyrings/"
+                "file:// URLs for keyrings must be under /usr/share/keyrings/ "
+                "or /usr/local/share/keyrings/"
             )
         return url
 
