@@ -80,10 +80,18 @@ class Sbuild(
         self._dsc_file: Path | None = None
         self._extra_packages: list[Path] = []
 
-    def compute_dynamic_data(
+    def build_dynamic_data(
         self, task_database: TaskDatabaseInterface
     ) -> SbuildDynamicData:
-        """Resolve artifact lookups for this task."""
+        """
+        Resolve artifact lookups for this task.
+
+        :subject: source package name
+        :runtime_context:
+          ``$build_components:$host_architecture:$build_architecture`` or
+          None if ``build_options`` is provided
+        :configuration_context: codename of ``environment``
+        """
         input_source_artifact = task_database.lookup_single_artifact(
             self.data.input.source_artifact
         )
