@@ -34,9 +34,16 @@ from debusine.client.models import (
     FilesResponseType,
     StrMaxLength255,
 )
-from debusine.tasks import BaseExternalTask, BaseTask
+from debusine.tasks import BaseExternalTask, BaseTask, BaseTaskWithExecutor
 from debusine.tasks.executors import ExecutorInterface, UnshareInstance
-from debusine.tasks.models import LookupMultiple, LookupSingle
+from debusine.tasks.models import (
+    BaseDynamicTaskData,
+    BaseDynamicTaskDataWithExecutor,
+    BaseTaskData,
+    BaseTaskDataWithExecutor,
+    LookupMultiple,
+    LookupSingle,
+)
 from debusine.tasks.server import (
     ArtifactInfo,
     MultipleArtifactInfo,
@@ -552,9 +559,34 @@ class ExternalTaskHelperMixin(
         )
 
 
-class TestTaskMixin:
-    """Common implementation of abstract task methods."""
+TD = TypeVar("TD", bound=BaseTaskData)
+DTD = TypeVar("DTD", bound=BaseDynamicTaskData)
+
+
+class TestBaseTask(BaseTask[TD, DTD]):
+    """Common test implementation of abstract task methods."""
 
     def get_label(self) -> str:
         """Return the task label."""
         return "test"
+
+    def build_dynamic_data(
+        self,
+        task_database: TaskDatabaseInterface,  # noqa: U100
+    ) -> DTD:
+        """Resolve artifact lookups for this task."""
+        return self.dynamic_task_data_type()
+
+
+class TestBaseExternalTask(TestBaseTask[TD, DTD], BaseExternalTask[TD, DTD]):
+    """Common test implementation of BaseExternalTask methods."""
+
+
+TDE = TypeVar("TDE", bound=BaseTaskDataWithExecutor)
+DTDE = TypeVar("DTDE", bound=BaseDynamicTaskDataWithExecutor)
+
+
+class TestBaseTaskWithExecutor(
+    TestBaseTask[TDE, DTDE], BaseTaskWithExecutor[TDE, DTDE]
+):
+    """Common test implementation of BaseExternalTask methods."""
