@@ -29,6 +29,7 @@ from debian.deb822 import Deb822
 from debusine.client.exceptions import ContentValidationError
 from debusine.tasks import TaskConfigError
 from debusine.tasks.models import (
+    BaseDynamicTaskData,
     SystemBootstrapData,
     SystemBootstrapRepository,
     SystemBootstrapRepositoryCheckSignatureWith,
@@ -36,7 +37,10 @@ from debusine.tasks.models import (
     SystemBootstrapRepositoryType,
 )
 from debusine.tasks.systembootstrap import SystemBootstrap
-from debusine.tasks.tests.helper_mixin import ExternalTaskHelperMixin
+from debusine.tasks.tests.helper_mixin import (
+    ExternalTaskHelperMixin,
+    FakeTaskDatabase,
+)
 from debusine.test import TestCase
 
 
@@ -56,7 +60,7 @@ class SystemBootstrapTests(
         "bootstrap_options": {
             "architecture": "amd64",
             "variant": "buildd",
-            "extra_packages": ["hello"],
+            "extra_packages": ["hello", "python3"],
         },
         "bootstrap_repositories": [
             {
@@ -128,6 +132,18 @@ class SystemBootstrapTests(
         with self.assertRaisesRegex(TaskConfigError, msg):
             self.configure_task(task_data)
 
+    def test_compute_dynamic_data(self) -> None:
+        task_database = FakeTaskDatabase()
+
+        self.assertEqual(
+            self.task.compute_dynamic_data(task_database),
+            BaseDynamicTaskData(
+                subject="bookworm",
+                runtime_context="amd64:buildd:hello,python3",
+                configuration_context="amd64",
+            ),
+        )
+
     @staticmethod
     def create_and_validate_repo(
         check_signature_with: SystemBootstrapRepositoryCheckSignatureWith,
@@ -747,8 +763,8 @@ class SystemBootstrapTests(
                 # Expect two: one from chroot, one from host sources
                 self.assertEqual(count, 2)
 
-        self.assertEqual(len(self.task._keyrings), 3)
-        self.assertEqual(len(self.task._upload_keyrings), 1)
+        self.assertEqual(len(self.task._keyrings), 1)
+        self.assertEqual(len(self.task._upload_keyrings), 0)
 
     def test_configure_for_execution_customization_script(self) -> None:
         """Test configure_for_execution() write customization_script."""
