@@ -55,6 +55,7 @@ from debusine.db.models import (
     CollectionItem,
     File,
     FileInArtifact,
+    Group,
     Token,
     User,
     WorkRequest,
@@ -63,7 +64,7 @@ from debusine.db.models import (
 )
 from debusine.tasks import BaseTask
 from debusine.tasks.models import TaskTypes
-from debusine.web.utils import ui_prototype
+from debusine.web.web_utils import ui_prototype
 
 if TYPE_CHECKING:
     ModelFormBase = ModelForm
@@ -624,3 +625,41 @@ class WorkspaceForm(BootstrapMixin, ModelFormBase[Workspace]):
             "expiration_delay": DaysField,
             "default_expiration_delay": DaysField,
         }
+
+
+class GroupAddUserForm(BootstrapMixin, Form):
+    """Form for adding a user to a group."""
+
+    username = CharField(required=True)
+
+    def __init__(self, group: Group, *args: Any, **kwargs: Any) -> None:
+        """Set the group the user would be added to."""
+        self.group = group
+        super().__init__(*args, **kwargs)
+
+    def clean(self) -> dict[str, Any]:
+        """
+        Validate username.
+
+        The user needs to exist and not be already a member of the group.
+        """
+        cleaned_data = super().clean()
+        assert cleaned_data is not None
+
+        if "username" not in cleaned_data:
+            return cleaned_data
+
+        try:
+            user = User.objects.get(username=cleaned_data["username"])
+        except User.DoesNotExist:
+            self.add_error(
+                "username", f"User {cleaned_data['username']} does not exist"
+            )
+            return cleaned_data
+
+        if self.group.users.filter(pk=user.pk).exists():
+            self.add_error(
+                "username", f"User is already a member of {self.group}"
+            )
+
+        return cleaned_data
