@@ -10,10 +10,9 @@
 """Tests for workflows."""
 
 from debusine.db.models import WorkRequest
-from debusine.server.tasks.wait import BaseWaitTask
+from debusine.server.tasks.tests.helpers import TestBaseWaitTask
 from debusine.server.workflows.models import WorkRequestWorkflowData
 from debusine.tasks.models import BaseDynamicTaskData, BaseTaskData, TaskTypes
-from debusine.tasks.tests.helper_mixin import TestTaskMixin
 from debusine.test.django import TestCase
 from debusine.web.templatetags.workflows import workflow_runtime_status_small
 
@@ -63,7 +62,7 @@ class WorkflowRuntimeStatusSmallTests(TestCase):
         )
 
         class WaitNoop(
-            TestTaskMixin, BaseWaitTask[BaseTaskData, BaseDynamicTaskData]
+            TestBaseWaitTask[BaseTaskData, BaseDynamicTaskData],
         ):
             TASK_VERSION = 1
 
