@@ -29,7 +29,14 @@ import yaml
 from debusine.artifacts import PackageBuildLog
 from debusine.artifacts.models import ArtifactCategory, DebianPackageBuildLog
 from debusine.db.context import context
-from debusine.db.models import Artifact, Token, User, WorkRequest, Workspace
+from debusine.db.models import (
+    Artifact,
+    Group,
+    Token,
+    User,
+    WorkRequest,
+    Workspace,
+)
 from debusine.db.playground import scenarios
 from debusine.tasks import BaseTask
 from debusine.test.django import TestCase
@@ -37,6 +44,7 @@ from debusine.web.forms import (
     ArtifactForm,
     BootstrapMixin,
     DaysField,
+    GroupAddUserForm,
     TokenForm,
     WorkRequestForm,
     WorkflowFilterForm,
@@ -946,3 +954,54 @@ class WorkspaceFormTests(TestCase):
         self.assertFalse(ws.public)
         self.assertEqual(ws.expiration_delay, timedelta(days=7))
         self.assertEqual(ws.default_expiration_delay, timedelta(days=14))
+
+
+class GroupAddUserFormTests(TestCase):
+    """Tests for GroupAddUserForm."""
+
+    scenario = scenarios.DefaultContext(set_current=True)
+
+    group: ClassVar[Group]
+
+    @classmethod
+    def setUpTestData(cls) -> None:
+        """Set up common data for tests."""
+        super().setUpTestData()
+        cls.group = cls.playground.create_group("test")
+
+    def _form(self, username: Any) -> GroupAddUserForm:
+        """Instantiate the form."""
+        return GroupAddUserForm(group=self.group, data={"username": username})
+
+    def test_username_required(self) -> None:
+        """A valid username passes validation."""
+        form = self._form(None)
+        self.assertFalse(form.is_valid())
+        self.assertEqual(form.errors, {"username": ["This field is required."]})
+
+    def test_valid_username(self) -> None:
+        """A valid username passes validation."""
+        form = self._form(self.scenario.user.username)
+        self.assertTrue(form.is_valid())
+        self.assertEqual(
+            form.cleaned_data["username"], self.scenario.user.username
+        )
+
+    def test_invalid_username(self) -> None:
+        """Error on invalid usernames."""
+        form = self._form("does-not-exist")
+        self.assertFalse(form.is_valid())
+        self.assertEqual(
+            form.errors, {"username": ["User does-not-exist does not exist"]}
+        )
+
+    def test_user_already_member(self) -> None:
+        """Existing members are not accepted."""
+        self.group.add_user(self.scenario.user)
+        form = self._form(self.scenario.user.username)
+        self.assertFalse(form.is_valid())
+        self.assertEqual(list(form.errors.keys()), ["username"])
+        self.assertEqual(
+            form.errors,
+            {"username": ["User is already a member of debusine/test"]},
+        )
