@@ -18,7 +18,6 @@ from django.http import Http404
 from debusine.db.context import context
 from debusine.db.models import Collection, CollectionItem
 from debusine.web.forms import CollectionSearchForm
-from debusine.web.utils import ui_prototype
 from debusine.web.views import sidebar, ui_shortcuts
 from debusine.web.views.base import (
     DetailViewBase,
@@ -27,7 +26,8 @@ from debusine.web.views.base import (
     WorkspaceView,
 )
 from debusine.web.views.base_rightbar import RightbarUIView
-from debusine.web.views.utils import PaginationMixin, format_yaml
+from debusine.web.views.view_utils import PaginationMixin, format_yaml
+from debusine.web.web_utils import ui_prototype
 
 
 class CollectionListView(WorkspaceView, ListViewBase[Collection]):
