@@ -33,8 +33,8 @@ from debusine.db.models.artifacts import (
     ARTIFACT_CATEGORY_SHORT_NAMES,
 )
 from debusine.web.icons import Icons
-from debusine.web.utils import ui_prototype
 from debusine.web.views.base import Widget
+from debusine.web.web_utils import ui_prototype
 
 
 @dataclass(kw_only=True)
