@@ -14,7 +14,7 @@ from typing import Any
 from debusine.db.models import Worker
 from debusine.tasks.models import WorkerType
 from debusine.web.views.base import BaseUIView, ListViewBase
-from debusine.web.views.utils import PaginationMixin
+from debusine.web.views.view_utils import PaginationMixin
 
 
 class WorkersListView(BaseUIView, PaginationMixin, ListViewBase[Worker]):
